# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: mangaplus_api.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13mangaplus_api.proto\x12\rmangaplus_api\"=\n\rAdNetworkList\x12,\n\nadNetworks\x18\x01 \x03(\x0b\x32\x18.mangaplus_api.AdNetwork\"k\n\x13\x41\x64RewardNetworkList\x12,\n\nadNetworks\x18\x01 \x03(\x0b\x32\x18.mangaplus_api.AdNetwork\x12\r\n\x05token\x18\x02 \x01(\t\x12\x17\n\x0frewardViewCount\x18\x03 \x01(\x05\"\x8d\x06\n\tAdNetwork\x12\x33\n\x08\x66\x61\x63\x65\x62ook\x18\x01 \x01(\x0b\x32!.mangaplus_api.AdNetwork.Facebook\x12-\n\x05\x61\x64mob\x18\x02 \x01(\x0b\x32\x1e.mangaplus_api.AdNetwork.Admob\x12-\n\x05mopub\x18\x03 \x01(\x0b\x32\x1e.mangaplus_api.AdNetwork.Mopub\x12\x31\n\x07\x61\x64sense\x18\x04 \x01(\x0b\x32 .mangaplus_api.AdNetwork.Adsense\x12\x33\n\x08\x61pplovin\x18\x05 \x01(\x0b\x32!.mangaplus_api.AdNetwork.Applovin\x12\x39\n\x0b\x61pplovinMax\x18\x06 \x01(\x0b\x32$.mangaplus_api.AdNetwork.ApplovinMax\x1a\x1f\n\x08\x46\x61\x63\x65\x62ook\x12\x13\n\x0bplacementID\x18\x01 \x01(\t\x1a\x17\n\x05\x41\x64mob\x12\x0e\n\x06unitID\x18\x01 \x01(\t\x1a+\n\x07\x41\x64sense\x12\x0e\n\x06unitID\x18\x01 \x01(\t\x12\x10\n\x08location\x18\x02 \x01(\t\x1a\x1a\n\x08\x41pplovin\x12\x0e\n\x06unitID\x18\x01 \x01(\t\x1a\x17\n\x05Mopub\x12\x0e\n\x06unitID\x18\x01 \x01(\t\x1aX\n\x0b\x41pplovinMax\x12\x0e\n\x06unitID\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\x05\x12\x13\n\x0b\x61mazonAppId\x18\x03 \x01(\t\x12\x16\n\x0e\x61mazonAdUnitId\x18\x04 \x01(\t\"`\n\x06\x41\x64Type\x12\x0f\n\x0bSTILL_IMAGE\x10\x00\x12\t\n\x05MOVIE\x10\x01\x12\x11\n\rNATIVE_MANUAL\x10\x02\x12\x11\n\rNATIVE_MEDIUM\x10\x03\x12\x08\n\x04MREC\x10\x04\x12\n\n\x06REWARD\x10\x05\"r\n\x0bNetworkCase\x12\x13\n\x0fNETWORK_NOT_SET\x10\x00\x12\x0c\n\x08\x46\x41\x43\x45\x42OOK\x10\x01\x12\t\n\x05\x41\x44MOB\x10\x02\x12\t\n\x05MOPUB\x10\x03\x12\x0b\n\x07\x41\x44SENSE\x10\x04\x12\x0c\n\x08\x41PPLOVIN\x10\x05\x12\x0f\n\x0b\x41PPLOVINMAX\x10\x06\"A\n\x11\x41llFreeTitlesView\x12,\n\nfreeTitles\x18\x01 \x03(\x0b\x32\x18.mangaplus_api.FreeTitle\"G\n\x13\x41llTicketTitlesView\x12\x30\n\x0bticketTitle\x18\x01 \x03(\x0b\x32\x1b.mangaplus_api.TicketTitles\"5\n\rAllTitlesView\x12$\n\x06titles\x18\x01 \x03(\x0b\x32\x14.mangaplus_api.Title\"H\n\x0f\x41llTitlesViewV2\x12\x35\n\x0e\x61llTitlesGroup\x18\x01 \x03(\x0b\x32\x1d.mangaplus_api.AllTitlesGroup\"\x84\x01\n\x06\x42\x61nner\x12\x10\n\x08imageUrl\x18\x01 \x01(\t\x12/\n\x06\x61\x63tion\x18\x02 \x01(\x0b\x32\x1f.mangaplus_api.TransitionAction\x12\n\n\x02id\x18\x03 \x01(\x05\x12\r\n\x05width\x18\x04 \x01(\x05\x12\x0e\n\x06height\x18\x05 \x01(\x05\x12\x0c\n\x04isPr\x18\x06 \x01(\x08\"\xb8\x02\n\x07\x43hapter\x12\x0f\n\x07titleId\x18\x01 \x01(\x05\x12\x11\n\tchapterId\x18\x02 \x01(\x05\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x10\n\x08subTitle\x18\x04 \x01(\t\x12\x14\n\x0cthumbnailUrl\x18\x05 \x01(\t\x12\x16\n\x0estartTimeStamp\x18\x06 \x01(\x03\x12\x14\n\x0c\x65ndTimeStamp\x18\x07 \x01(\x03\x12\x15\n\ralreadyViewed\x18\x08 \x01(\x08\x12\x16\n\x0eisVerticalOnly\x18\t \x01(\x08\x12\x1c\n\x14\x63hapterTicketEndtime\x18\n \x01(\x05\x12\x15\n\rviewedForFree\x18\x0b \x01(\x08\x12\x18\n\x10isHorizontalOnly\x18\x0c \x01(\x08\x12\x11\n\tviewCount\x18\r \x01(\x05\x12\x14\n\x0c\x63ommentCount\x18\x0e \x01(\x05\"+\n\x0b\x43ommentIcon\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x10\n\x08imageUrl\x18\x02 \x01(\t\"\x80\x02\n\x0f\x43ommentListView\x12(\n\x08\x63omments\x18\x01 \x03(\x0b\x32\x16.mangaplus_api.Comment\x12\x15\n\rifSetUserName\x18\x02 \x01(\x08\x12M\n\x12titleDetailComment\x18\x03 \x01(\x0b\x32\x31.mangaplus_api.CommentListView.TitleDetailComment\x1a]\n\x12TitleDetailComment\x12\x0f\n\x07titleId\x18\x01 \x01(\x05\x12\x11\n\ttitleName\x18\x02 \x01(\t\x12\x13\n\x0b\x63hapterName\x18\x03 \x01(\t\x12\x0e\n\x06\x63redit\x18\x04 \x01(\t\"\xa8\x01\n\x07\x43omment\x12\n\n\x02id\x18\x01 \x01(\x05\x12\r\n\x05index\x18\x02 \x01(\x05\x12\x10\n\x08userName\x18\x03 \x01(\t\x12\x0f\n\x07iconUrl\x18\x04 \x01(\t\x12\x13\n\x0bisMyComment\x18\x06 \x01(\x08\x12\x14\n\x0c\x61lreadyLiked\x18\x07 \x01(\x08\x12\x15\n\rnumberOfLikes\x18\t \x01(\x05\x12\x0c\n\x04\x62ody\x18\n \x01(\t\x12\x0f\n\x07\x63reated\x18\x0b \x01(\x05\"\x8f\x01\n\x10\x46reeViewDialogue\x12\x36\n\x08platform\x18\x01 \x01(\x0e\x32$.mangaplus_api.FirstTimeFreePlatform\x12\x13\n\x0b\x64ialogueUrl\x18\x02 \x01(\t\x12.\n\x0fpublisherBanner\x18\x03 \x01(\x0b\x32\x15.mangaplus_api.Banner\"[\n\x16\x44ownloadableImagesView\x12\x41\n\x12\x64ownloadableImages\x18\x01 \x03(\x0b\x32%.mangaplus_api.DownloadableImageGroup\"w\n\x16\x44ownloadableImageGroup\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x10\n\x08imageUrl\x18\x02 \x01(\t\x12\x12\n\nimageTitle\x18\x03 \x01(\t\x12\r\n\x05width\x18\x04 \x01(\x05\x12\x0e\n\x06height\x18\x05 \x01(\x05\x12\x0c\n\x04type\x18\x06 \x01(\t\"\xbd\x02\n\x0b\x45rrorResult\x12\x31\n\x06\x61\x63tion\x18\x01 \x01(\x0e\x32!.mangaplus_api.ErrorResult.Action\x12\x34\n\x0c\x65nglishPopup\x18\x02 \x01(\x0b\x32\x1e.mangaplus_api.Popup.OSDefault\x12\x34\n\x0cspanishPopup\x18\x03 \x01(\x0b\x32\x1e.mangaplus_api.Popup.OSDefault\x12\x11\n\tdebugInfo\x18\x04 \x01(\t\x12.\n\x06popups\x18\x05 \x03(\x0b\x32\x1e.mangaplus_api.Popup.OSDefault\"L\n\x06\x41\x63tion\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x00\x12\x10\n\x0cUNAUTHORIZED\x10\x01\x12\x0f\n\x0bMAINTENANCE\x10\x02\x12\x12\n\x0eGEOIP_BLOCKING\x10\x03\"\x8e\x01\n\x12\x46\x61voriteTitlesView\x12=\n\x12\x61vailableLanguages\x18\x01 \x03(\x0b\x32!.mangaplus_api.AvailableLanguages\x12\x39\n\x0e\x66\x61voriteTitles\x18\x02 \x03(\x0b\x32!.mangaplus_api.FavoriteTitleGroup\"e\n\x12\x46\x61voriteTitleGroup\x12)\n\x08language\x18\x01 \x01(\x0e\x32\x17.mangaplus_api.Language\x12$\n\x06titles\x18\x02 \x03(\x0b\x32\x14.mangaplus_api.Title\"\x8a\x03\n\x12\x46\x65\x61turedTitlesView\x12)\n\nmainBanner\x18\x01 \x01(\x0b\x32\x15.mangaplus_api.Banner\x12)\n\nsubBanner1\x18\x02 \x01(\x0b\x32\x15.mangaplus_api.Banner\x12)\n\nsubBanner2\x18\x03 \x01(\x0b\x32\x15.mangaplus_api.Banner\x12<\n\x08\x63ontents\x18\x04 \x03(\x0b\x32*.mangaplus_api.FeaturedTitlesView.Contents\x1a\xb4\x01\n\x08\x43ontents\x12\x41\n\x04\x64\x61ta\x18\x01 \x01(\x0e\x32\x33.mangaplus_api.FeaturedTitlesView.Contents.DataCase\x12+\n\ttitleList\x18\x02 \x01(\x0b\x32\x18.mangaplus_api.TitleList\"8\n\x08\x44\x61taCase\x12\x10\n\x0c\x44\x41TA_NOT_SET\x10\x00\x12\n\n\x06\x42\x41NNER\x10\x01\x12\x0e\n\nTITLE_LIST\x10\x02\"\xa0\x02\n\x14\x46\x65\x61turedTitlesViewV2\x12/\n\x10topSearchBanners\x18\x01 \x03(\x0b\x32\x15.mangaplus_api.Banner\x12>\n\x08\x63ontents\x18\x02 \x03(\x0b\x32,.mangaplus_api.FeaturedTitlesViewV2.Contents\x1a\x96\x01\n\x08\x43ontents\x12%\n\x06\x62\x61nner\x18\x01 \x01(\x0b\x32\x15.mangaplus_api.Banner\x12+\n\ttitleList\x18\x02 \x01(\x0b\x32\x18.mangaplus_api.TitleList\x12\x36\n\x0crankedTitles\x18\x03 \x03(\x0b\x32 .mangaplus_api.TitleRankingGroup\"\x91\x01\n\x08\x46\x65\x65\x64\x62\x61\x63k\x12\x11\n\ttimeStamp\x18\x01 \x01(\x03\x12\x0c\n\x04\x62ody\x18\x02 \x01(\t\x12:\n\x0cresponseType\x18\x03 \x01(\x0e\x32$.mangaplus_api.Feedback.ResponseType\"(\n\x0cResponseType\x12\x0c\n\x08QUESTION\x10\x00\x12\n\n\x06\x41NSWER\x10\x01\"=\n\x0c\x46\x65\x65\x64\x62\x61\x63kView\x12-\n\x0c\x66\x65\x65\x64\x62\x61\x63kList\x18\x01 \x03(\x0b\x32\x17.mangaplus_api.Feedback\"g\n\x0bHistoryView\x12-\n\x0ehistoryBanners\x18\x01 \x03(\x0b\x32\x15.mangaplus_api.Banner\x12)\n\x0bviewHistory\x18\x02 \x03(\x0b\x32\x14.mangaplus_api.Title\"\xa7\x02\n\nHomeViewV3\x12)\n\ntopBanners\x18\x01 \x03(\x0b\x32\x15.mangaplus_api.Banner\x12\x32\n\x06groups\x18\x02 \x03(\x0b\x32\".mangaplus_api.UpdatedTitleV2Group\x12#\n\x05popup\x18\t \x01(\x0b\x32\x14.mangaplus_api.Popup\x12\x1c\n\x14\x64isplayTrackingPopup\x18\n \x01(\x08\x12\x35\n\x10userSubscription\x18\x0b \x01(\x0b\x32\x1b.mangaplus_api.Subscription\x12@\n\x14serviceAnnouncements\x18\x0c \x03(\x0b\x32\".mangaplus_api.ServiceAnnouncement\"\xae\x12\n\nHomeViewV4\x12\x34\n\x08sections\x18\x01 \x03(\x0b\x32\".mangaplus_api.HomeViewV4.Sections\x12#\n\x05popup\x18\x02 \x01(\x0b\x32\x14.mangaplus_api.Popup\x12\x1c\n\x14\x64isplayTrackingPopup\x18\x03 \x01(\x08\x12\x35\n\x10userSubscription\x18\x04 \x01(\x0b\x32\x1b.mangaplus_api.Subscription\x12@\n\x14serviceAnnouncements\x18\x05 \x03(\x0b\x32\".mangaplus_api.ServiceAnnouncement\x1a\xe3\x03\n\x08Sections\x12>\n\rweeklySection\x18\x01 \x01(\x0b\x32\'.mangaplus_api.HomeViewV4.WeeklySection\x12@\n\x0erankingSection\x18\x02 \x01(\x0b\x32(.mangaplus_api.HomeViewV4.RankingSection\x12@\n\x0epreviewSection\x18\x03 \x01(\x0b\x32(.mangaplus_api.HomeViewV4.PreviewSection\x12\x44\n\x10titleListSection\x18\x04 \x01(\x0b\x32*.mangaplus_api.HomeViewV4.TitleListSection\x12>\n\rbannerSection\x18\x05 \x01(\x0b\x32\'.mangaplus_api.HomeViewV4.BannerSection\"\x8c\x01\n\x0bSectionCase\x12\x13\n\x0fSECTION_NOT_SET\x10\x00\x12\x12\n\x0eWEEKLY_SECTION\x10\x01\x12\x13\n\x0fRANKING_SECTION\x10\x02\x12\x13\n\x0fPREVIEW_SECTION\x10\x03\x12\x16\n\x12TITLE_LIST_SECTION\x10\x04\x12\x12\n\x0e\x42\x41NNER_SECTION\x10\x05\x1a\xa5\x08\n\rWeeklySection\x12G\n\x08\x63ontents\x18\x01 \x03(\x0b\x32\x35.mangaplus_api.HomeViewV4.WeeklySection.WeeklyContent\x1a\x87\x01\n\rWeeklyContent\x12\x11\n\tisUpdated\x18\x01 \x01(\x08\x12\x18\n\x10updatedTimeStamp\x18\x02 \x01(\x03\x12I\n\x0c\x63ontentItems\x18\x03 \x03(\x0b\x32\x33.mangaplus_api.HomeViewV4.WeeklySection.ContentItem\x1a\x9b\x04\n\x0b\x43ontentItem\x12P\n\x07\x63ontent\x18\x01 \x01(\x0e\x32?.mangaplus_api.HomeViewV4.WeeklySection.ContentItem.ContentCase\x12\x42\n\x08mVBanner\x18\x02 \x01(\x0b\x32\x30.mangaplus_api.HomeViewV4.WeeklySection.MVBanner\x12\x46\n\ntitleGroup\x18\x03 \x01(\x0b\x32\x32.mangaplus_api.HomeViewV4.WeeklySection.TitleGroup\x12O\n\x0f\x63\x61rouselBanners\x18\x04 \x01(\x0b\x32\x36.mangaplus_api.HomeViewV4.WeeklySection.CarouselBanner\x12X\n\x13minorLanguageBanner\x18\x05 \x01(\x0b\x32;.mangaplus_api.HomeViewV4.WeeklySection.MinorLanguageBanner\"\x82\x01\n\x0b\x43ontentCase\x12\x13\n\x0f\x43ONTENT_NOT_SET\x10\x00\x12\r\n\tPR_BANNER\x10\x01\x12\r\n\tMV_BANNER\x10\x02\x12\x0f\n\x0bTITLE_GROUP\x10\x03\x12\x14\n\x10\x43\x41ROUSEL_BANNERS\x10\x04\x12\x19\n\x15MINOR_LANGUAGE_BANNER\x10\x05\x1aT\n\x08MVBanner\x12\x10\n\x08imageUrl\x18\x01 \x01(\t\x12\x36\n\x0btitleGroups\x18\x02 \x01(\x0b\x32!.mangaplus_api.OriginalTitleGroup\x1a\x44\n\nTitleGroup\x12\x36\n\x0btitleGroups\x18\x01 \x03(\x0b\x32!.mangaplus_api.OriginalTitleGroup\x1a\x38\n\x0e\x43\x61rouselBanner\x12&\n\x07\x62\x61nners\x18\x01 \x03(\x0b\x32\x15.mangaplus_api.Banner\x1aM\n\x13MinorLanguageBanner\x12\x36\n\x0btitleGroups\x18\x01 \x03(\x0b\x32!.mangaplus_api.OriginalTitleGroup\x1a\xd0\x01\n\x0eRankingSection\x12H\n\x0brankingTabs\x18\x01 \x03(\x0b\x32\x33.mangaplus_api.HomeViewV4.RankingSection.RankingTab\x1at\n\nRankingTab\x12.\n\x07tabType\x18\x01 \x01(\x0e\x32\x1d.mangaplus_api.RankingTabType\x12\x36\n\x0crankedTitles\x18\x02 \x03(\x0b\x32 .mangaplus_api.TitleRankingGroup\x1a\xd2\x01\n\x0ePreviewSection\x12H\n\x0bpreviewTabs\x18\x01 \x03(\x0b\x32\x33.mangaplus_api.HomeViewV4.PreviewSection.PreviewTab\x1av\n\nPreviewTab\x12.\n\x07tabType\x18\x01 \x01(\x0e\x32\x1d.mangaplus_api.RankingTabType\x12\x38\n\x10\x63hapterPagesList\x18\x02 \x01(\x0b\x32\x1e.mangaplus_api.ChapterPageList\x1a?\n\x10TitleListSection\x12+\n\ttitleList\x18\x01 \x01(\x0b\x32\x18.mangaplus_api.TitleList\x1a\x37\n\rBannerSection\x12&\n\x07\x62\x61nners\x18\x01 \x03(\x0b\x32\x15.mangaplus_api.Banner\"m\n\rInitialViewV2\x12\x1d\n\x15gdprAgreementRequired\x18\x01 \x01(\x08\x12=\n\x12\x61vailableLanguages\x18\x02 \x03(\x0b\x32!.mangaplus_api.AvailableLanguages\"_\n\x15IntroduceSubscription\x12\x14\n\x0csubscription\x18\x01 \x01(\t\x12\x16\n\x0etitleCountText\x18\x02 \x01(\t\x12\x18\n\x10\x63hapterCountText\x18\x03 \x01(\t\"q\n\x0bLabeledView\x12#\n\x05label\x18\x01 \x01(\x0b\x32\x14.mangaplus_api.Label\x12=\n\x12labeledTitlesGroup\x18\x02 \x03(\x0b\x32!.mangaplus_api.LabeledTitlesGroup\"F\n\x05Label\x12(\n\x05label\x18\x01 \x01(\x0e\x32\x19.mangaplus_api.LabelCodes\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\"\xb4\x02\n\tLanguages\x12\x32\n\x11\x64\x65\x66\x61ultUiLanguage\x18\x01 \x01(\x0e\x32\x17.mangaplus_api.Language\x12:\n\x19\x64\x65\x66\x61ultContentLanguageOne\x18\x02 \x01(\x0e\x32\x17.mangaplus_api.Language\x12:\n\x19\x64\x65\x66\x61ultContentLanguageTwo\x18\x03 \x01(\x0e\x32\x17.mangaplus_api.Language\x12<\n\x1b\x64\x65\x66\x61ultContentLanguageThree\x18\x04 \x01(\x0e\x32\x17.mangaplus_api.Language\x12=\n\x12\x61vailableLanguages\x18\x05 \x03(\x0b\x32!.mangaplus_api.AvailableLanguages\"T\n\x12\x41vailableLanguages\x12)\n\x08language\x18\x01 \x01(\x0e\x32\x17.mangaplus_api.Language\x12\x13\n\x0btitlesCount\x18\x02 \x01(\x05\"\xab\x05\n\x0bMangaViewer\x12\"\n\x05pages\x18\x01 \x03(\x0b\x32\x13.mangaplus_api.Page\x12\x11\n\tchapterId\x18\x02 \x01(\x05\x12(\n\x08\x63hapters\x18\x03 \x03(\x0b\x32\x16.mangaplus_api.Chapter\x12\x1f\n\x03sns\x18\x04 \x01(\x0b\x32\x12.mangaplus_api.Sns\x12\x11\n\ttitleName\x18\x05 \x01(\t\x12\x13\n\x0b\x63hapterName\x18\x06 \x01(\t\x12\x18\n\x10numberOfComments\x18\x07 \x01(\x05\x12\x16\n\x0eisVerticalOnly\x18\x08 \x01(\x08\x12\x0f\n\x07titleId\x18\t \x01(\x05\x12\x16\n\x0estartFromRight\x18\n \x01(\x08\x12\x12\n\nregionCode\x18\x0b \x01(\t\x12\x18\n\x10isHorizontalOnly\x18\x0c \x01(\x08\x12\x35\n\x10userSubscription\x18\r \x01(\x0b\x32\x1b.mangaplus_api.Subscription\x12\x10\n\x08planType\x18\x0e \x01(\t\x12\x15\n\rtitleLanguage\x18\x0f \x01(\t\x12)\n\x0bratingPopup\x18\x10 \x01(\x0b\x32\x14.mangaplus_api.Popup\x12S\n\x17titleAvailableLanguages\x18\x11 \x03(\x0b\x32\x32.mangaplus_api.MangaViewer.TitleAvailableLanguages\x12#\n\x05title\x18\x12 \x01(\x0b\x32\x14.mangaplus_api.Title\x1a\x64\n\x17TitleAvailableLanguages\x12\x0f\n\x07titleId\x18\x01 \x01(\x05\x12)\n\x08language\x18\x02 \x01(\x0e\x32\x17.mangaplus_api.Language\x12\r\n\x05isNew\x18\x03 \x01(\x08\"6\n\x08MetaInfo\x12\x11\n\tmetaTitle\x18\x01 \x01(\t\x12\x17\n\x0fmetaDescription\x18\x02 \x01(\t\"E\n\rMpcStatusView\x12\x18\n\x10isMpcMaintenance\x18\x01 \x01(\x08\x12\x1a\n\x12maintenanceMessage\x18\x02 \x01(\t\"\xfc\x0b\n\x04Page\x12\x30\n\tmangaPage\x18\x01 \x01(\x0b\x32\x1d.mangaplus_api.Page.MangaPage\x12\x32\n\nbannerList\x18\x02 \x01(\x0b\x32\x1e.mangaplus_api.Page.BannerList\x12.\n\x08lastPage\x18\x03 \x01(\x0b\x32\x1c.mangaplus_api.Page.LastPage\x12\x39\n\radvertisement\x18\x04 \x01(\x0b\x32\".mangaplus_api.AdRewardNetworkList\x12\x38\n\x10insertBannerList\x18\x05 \x01(\x0b\x32\x1e.mangaplus_api.Page.BannerList\x1a\x7f\n\tMangaPage\x12\x10\n\x08imageUrl\x18\x01 \x01(\t\x12\r\n\x05width\x18\x02 \x01(\x05\x12\x0e\n\x06height\x18\x03 \x01(\x05\x12*\n\x04type\x18\x04 \x01(\x0e\x32\x1c.mangaplus_api.Page.PageType\x12\x15\n\rencryptionKey\x18\x05 \x01(\t\x1a\xb1\x06\n\x08LastPage\x12.\n\x0e\x63urrentChapter\x18\x01 \x01(\x0b\x32\x16.mangaplus_api.Chapter\x12+\n\x0bnextChapter\x18\x02 \x01(\x0b\x32\x16.mangaplus_api.Chapter\x12+\n\x0btopComments\x18\x03 \x03(\x0b\x32\x16.mangaplus_api.Comment\x12\x14\n\x0cisSubscribed\x18\x04 \x01(\x08\x12\x15\n\rnextTimeStamp\x18\x05 \x01(\x03\x12\x34\n\x0b\x63hapterType\x18\x06 \x01(\x0e\x32\x1f.mangaplus_api.Page.ChapterType\x12\x33\n\radvertisement\x18\x07 \x01(\x0b\x32\x1c.mangaplus_api.AdNetworkList\x12)\n\x0bmovieReward\x18\x08 \x01(\x0b\x32\x14.mangaplus_api.Popup\x12&\n\x07\x62\x61nners\x18\t \x03(\x0b\x32\x15.mangaplus_api.Banner\x12-\n\x0fticketTitleList\x18\n \x03(\x0b\x32\x14.mangaplus_api.Title\x12.\n\x0fpublisherBanner\x18\x0b \x01(\x0b\x32\x15.mangaplus_api.Banner\x12/\n\x0buserTickets\x18\x0c \x01(\x0b\x32\x1a.mangaplus_api.UserTickets\x12!\n\x19isNextChapterReadByTicket\x18\r \x01(\x08\x12 \n\x18isNextChapterOneTimeFree\x18\x0e \x01(\x08\x12\x39\n\x10\x66reeViewDialogue\x18\x0f \x01(\x0b\x32\x1f.mangaplus_api.FreeViewDialogue\x12!\n\x19isNextChapterSubscription\x18\x10 \x01(\x08\x12?\n\x13\x61\x64vertisementReward\x18\x11 \x01(\x0b\x32\".mangaplus_api.AdRewardNetworkList\x12<\n\x16viewerEndAdvertisement\x18\x12 \x01(\x0b\x32\x1c.mangaplus_api.AdNetworkList\x1aI\n\nBannerList\x12\x13\n\x0b\x62\x61nnerTitle\x18\x01 \x01(\t\x12&\n\x07\x62\x61nners\x18\x02 \x03(\x0b\x32\x15.mangaplus_api.Banner\"7\n\x0b\x43hapterType\x12\n\n\x06LATEST\x10\x00\x12\x0c\n\x08SEQUENCE\x10\x01\x12\x0e\n\nNOSEQUENCE\x10\x02\"7\n\x08PageType\x12\n\n\x06SINGLE\x10\x00\x12\x08\n\x04LEFT\x10\x01\x12\t\n\x05RIGHT\x10\x02\x12\n\n\x06\x44OUBLE\x10\x03\"w\n\x08\x44\x61taCase\x12\x10\n\x0c\x44\x41TA_NOT_SET\x10\x00\x12\x0e\n\nMANGA_PAGE\x10\x01\x12\x0f\n\x0b\x42\x41NNER_LIST\x10\x02\x12\r\n\tLAST_PAGE\x10\x03\x12\x11\n\rADVERTISEMENT\x10\x04\x12\x16\n\x12INSERT_BANNER_LIST\x10\x05\"\xba\x06\n\x05Popup\x12\x31\n\toSDefault\x18\x01 \x01(\x0b\x32\x1e.mangaplus_api.Popup.OSDefault\x12\x33\n\nappDefault\x18\x02 \x01(\x0b\x32\x1f.mangaplus_api.Popup.AppDefault\x12/\n\x0bmovieReward\x18\x03 \x01(\x0b\x32\x1a.mangaplus_api.MovieReward\x12/\n\x08oneImage\x18\x04 \x01(\x0b\x32\x1d.mangaplus_api.Popup.OneImage\x12\x0f\n\x07popupId\x18\x05 \x01(\x05\x1a\xeb\x01\n\tOSDefault\x12\x0f\n\x07subject\x18\x01 \x01(\t\x12\x0c\n\x04\x62ody\x18\x02 \x01(\t\x12-\n\x08okButton\x18\x03 \x01(\x0b\x32\x1b.mangaplus_api.Popup.Button\x12\x32\n\rneutralButton\x18\x04 \x01(\x0b\x32\x1b.mangaplus_api.Popup.Button\x12\x31\n\x0c\x63\x61ncelButton\x18\x05 \x01(\x0b\x32\x1b.mangaplus_api.Popup.Button\x12)\n\x08language\x18\x06 \x01(\x0e\x32\x17.mangaplus_api.Language\x1an\n\nAppDefault\x12\x0f\n\x07subject\x18\x01 \x01(\t\x12\x0c\n\x04\x62ody\x18\x02 \x01(\t\x12/\n\x06\x61\x63tion\x18\x03 \x01(\x0b\x32\x1f.mangaplus_api.TransitionAction\x12\x10\n\x08imageUrl\x18\x04 \x01(\t\x1aM\n\x08OneImage\x12/\n\x06\x61\x63tion\x18\x01 \x01(\x0b\x32\x1f.mangaplus_api.TransitionAction\x12\x10\n\x08imageUrl\x18\x02 \x01(\t\x1aG\n\x06\x42utton\x12\x0c\n\x04text\x18\x01 \x01(\t\x12/\n\x06\x61\x63tion\x18\x02 \x01(\x0b\x32\x1f.mangaplus_api.TransitionAction\"`\n\tPopupCase\x12\x11\n\rPOPUP_NOT_SET\x10\x00\x12\x0e\n\nOS_DEFAULT\x10\x01\x12\x0f\n\x0b\x41PP_DEFAULT\x10\x02\x12\x10\n\x0cMOVIE_REWARD\x10\x03\x12\r\n\tONE_IMAGE\x10\x04\"T\n\x0bMovieReward\x12\x10\n\x08imageUrl\x18\x01 \x01(\t\x12\x33\n\radvertisement\x18\x02 \x01(\x0b\x32\x1c.mangaplus_api.AdNetworkList\"\x81\x01\n\x13ProfileSettingsView\x12,\n\x08iconList\x18\x01 \x03(\x0b\x32\x1a.mangaplus_api.CommentIcon\x12\x10\n\x08userName\x18\x02 \x01(\t\x12*\n\x06myIcon\x18\x03 \x01(\x0b\x32\x1a.mangaplus_api.CommentIcon\"\x9a\x01\n\x15PublisherNewsListView\x12\x13\n\x0bpublisherId\x18\x01 \x01(\x05\x12\x15\n\rpublisherName\x18\x02 \x01(\t\x12%\n\x06\x62\x61nner\x18\x03 \x01(\x0b\x32\x15.mangaplus_api.Banner\x12.\n\x08newsList\x18\x04 \x03(\x0b\x32\x1c.mangaplus_api.PublisherNews\"\xb3\x01\n\rPublisherNews\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x13\n\x0bpublisherId\x18\x02 \x01(\x05\x12\x15\n\rpublisherName\x18\x03 \x01(\t\x12\x0f\n\x07subject\x18\x04 \x01(\t\x12\x0c\n\x04\x62ody\x18\x05 \x01(\t\x12\x1a\n\x12publishedTimeStamp\x18\x06 \x01(\x03\x12/\n\x06\x61\x63tion\x18\x07 \x01(\x0b\x32\x1f.mangaplus_api.TransitionAction\"6\n\rPushTokenView\x12\r\n\x05token\x18\x01 \x01(\t\x12\x16\n\x0etokenTimeStamp\x18\x02 \x01(\x03\"\x89\x01\n\rQuestionnaire\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x11\n\tselection\x18\x02 \x03(\t\x12\x17\n\x0fnumberOfChoices\x18\x03 \x01(\x05\x12\x14\n\x0chideFreeform\x18\x04 \x01(\x08\x12\x10\n\x08\x66reeForm\x18\x05 \x01(\t\x12\x0f\n\x07\x63\x61nSkip\x18\x06 \x01(\x08\"\x94\x01\n\x11QuestionnaireView\x12\x12\n\nisAnswered\x18\x01 \x01(\x08\x12\x0f\n\x07subject\x18\x02 \x01(\t\x12/\n\tquestions\x18\x03 \x03(\x0b\x32\x1c.mangaplus_api.Questionnaire\x12)\n\x08language\x18\x04 \x01(\x0e\x32\x17.mangaplus_api.Language\"(\n\x10RegistrationData\x12\x14\n\x0c\x64\x65viceSecret\x18\x01 \x01(\t\"\x9e\x01\n\x08Response\x12-\n\x07success\x18\x01 \x01(\x0b\x32\x1c.mangaplus_api.SuccessResult\x12)\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x1a.mangaplus_api.ErrorResult\"8\n\nResultCase\x12\x12\n\x0eRESULT_NOT_SET\x10\x00\x12\x0b\n\x07SUCCESS\x10\x01\x12\t\n\x05\x45RROR\x10\x02\"\xcb\x03\n\nSearchView\x12/\n\x10topSearchBanners\x18\x01 \x03(\x0b\x32\x15.mangaplus_api.Banner\x12#\n\x07\x61llTags\x18\x02 \x03(\x0b\x32\x12.mangaplus_api.Tag\x12\x35\n\x0e\x61llTitlesGroup\x18\x03 \x03(\x0b\x32\x1d.mangaplus_api.AllTitlesGroup\x12\x34\n\x08\x63ontents\x18\x05 \x03(\x0b\x32\".mangaplus_api.SearchView.Contents\x1a\xf9\x01\n\x08\x43ontents\x12%\n\x06\x62\x61nner\x18\x01 \x01(\x0b\x32\x15.mangaplus_api.Banner\x12+\n\ttitleList\x18\x02 \x01(\x0b\x32\x18.mangaplus_api.TitleList\x12\x36\n\x0crankedTitles\x18\x03 \x03(\x0b\x32 .mangaplus_api.TitleRankingGroup\x12\'\n\tallLabels\x18\x04 \x03(\x0b\x32\x14.mangaplus_api.Label\x12\x38\n\x10\x63hapterPagesList\x18\x05 \x01(\x0b\x32\x1e.mangaplus_api.ChapterPageList\"L\n\x13ServiceAnnouncement\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0c\n\x04\x62ody\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x61te\x18\x03 \x01(\x03\x12\n\n\x02id\x18\x04 \x01(\x05\"\\\n\x18ServiceAnnouncementsView\x12@\n\x14serviceAnnouncements\x18\x01 \x03(\x0b\x32\".mangaplus_api.ServiceAnnouncement\"\xce\x01\n\x0cSettingsView\x12*\n\x06myIcon\x18\x01 \x01(\x0b\x32\x1a.mangaplus_api.CommentIcon\x12\x10\n\x08userName\x18\x02 \x01(\t\x12\x1d\n\x15noticeOfNewsAndEvents\x18\x03 \x01(\x08\x12)\n!noticeOfUpdatesOfSubscribedTitles\x18\x04 \x01(\x08\x12\x1a\n\x12\x65nglishTitlesCount\x18\x05 \x01(\x05\x12\x1a\n\x12spanishTitlesCount\x18\x06 \x01(\x05\"\xb0\x03\n\x0eSettingsViewV2\x12*\n\x06myIcon\x18\x01 \x01(\x0b\x32\x1a.mangaplus_api.CommentIcon\x12\x10\n\x08userName\x18\x02 \x01(\t\x12\x1d\n\x15noticeOfNewsAndEvents\x18\x03 \x01(\x08\x12)\n!noticeOfUpdatesOfSubscribedTitles\x18\x04 \x01(\x08\x12=\n\x12\x61vailableLanguages\x18\x05 \x03(\x0b\x32!.mangaplus_api.AvailableLanguages\x12\x35\n\x10userSubscription\x18\x06 \x01(\x0b\x32\x1b.mangaplus_api.Subscription\x12%\n\x06\x62\x61nner\x18\x07 \x01(\x0b\x32\x15.mangaplus_api.Banner\x12?\n\x14\x61vailableCustomCodes\x18\x08 \x03(\x0b\x32!.mangaplus_api.CustomCodeDialogue\x12\x38\n\x0e\x66\x61voriteTitles\x18\t \x03(\x0b\x32 .mangaplus_api.TitleRankingGroup\"&\n\x12\x43ustomCodeDialogue\x12\x10\n\x08planType\x18\x01 \x01(\t\" \n\x03Sns\x12\x0c\n\x04\x62ody\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\"\x96\x01\n\x14SubscribedTitlesView\x12$\n\x06titles\x18\x01 \x03(\x0b\x32\x14.mangaplus_api.Title\x12-\n\x0ehistoryBanners\x18\x02 \x03(\x0b\x32\x15.mangaplus_api.Banner\x12)\n\x0bviewHistory\x18\x03 \x03(\x0b\x32\x14.mangaplus_api.Title\"\xf1\x01\n\x14IosSubscriptionOffer\x12@\n\tofferType\x18\x01 \x01(\x0e\x32-.mangaplus_api.IosSubscriptionOffer.OfferType\x12\x11\n\tsignature\x18\x02 \x01(\t\x12\x10\n\x08\x61ppleKey\x18\x03 \x01(\t\x12\r\n\x05nonce\x18\x04 \x01(\t\x12\x11\n\ttimestamp\x18\x05 \x01(\t\x12\x12\n\nidentifier\x18\x06 \x01(\t\"<\n\tOfferType\x12\x0c\n\x08NO_OFFER\x10\x00\x12\x10\n\x0cINTRODUCTORY\x10\x01\x12\x0f\n\x0bPROMOTIONAL\x10\x02\"+\n\x1c\x41ndroidSubscriptionOfferTags\x12\x0b\n\x03tag\x18\x01 \x01(\t\"\x83\x01\n\x0cSubscription\x12\x10\n\x08planType\x18\x01 \x01(\t\x12\x17\n\x0fnextPaymentDate\x18\x02 \x01(\x05\x12\x13\n\x0bisFreeTrial\x18\x03 \x01(\x08\x12\x1a\n\x12isPendingDowngrade\x18\x04 \x01(\x08\x12\x17\n\x0fisFirstTimeUser\x18\x05 \x01(\x08\"\xc7\x01\n\x08PlanType\x12\x0c\n\x04plan\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x11\n\tproductId\x18\x03 \x01(\t\x12>\n\x11subscriptionOffer\x18\x04 \x01(\x0b\x32#.mangaplus_api.IosSubscriptionOffer\x12\x45\n\x10\x61ndroidOfferTags\x18\x05 \x03(\x0b\x32+.mangaplus_api.AndroidSubscriptionOfferTags\"\xf3\x02\n\x10SubscriptionView\x12\x35\n\x10userSubscription\x18\x01 \x01(\x0b\x32\x1b.mangaplus_api.Subscription\x12*\n\tplanTypes\x18\x02 \x03(\x0b\x32\x17.mangaplus_api.PlanType\x12\x41\n\x12subscriptionTitles\x18\x03 \x03(\x0b\x32%.mangaplus_api.TitleSubscriptionGroup\x12\x18\n\x10userHasUsedTrial\x18\x04 \x01(\x08\x12%\n\x06\x62\x61nner\x18\x05 \x01(\x0b\x32\x15.mangaplus_api.Banner\x12I\n\x12planBoxDescription\x18\x06 \x01(\x0b\x32-.mangaplus_api.SubscriptionPlanBoxDescription\x12-\n\x04note\x18\x07 \x01(\x0b\x32\x1f.mangaplus_api.SubscriptionNote\"=\n\x1eSubscriptionPlanBoxDescription\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0c\n\x04text\x18\x02 \x01(\t\"/\n\x10SubscriptionNote\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0c\n\x04text\x18\x02 \x01(\t\"\xa5\x18\n\rSuccessResult\x12\x19\n\x11isFeaturedUpdated\x18\x01 \x01(\x08\x12:\n\x11registerationData\x18\x02 \x01(\x0b\x32\x1f.mangaplus_api.RegistrationData\x12=\n\x12\x66\x65\x61turedTitlesView\x18\x04 \x01(\x0b\x32!.mangaplus_api.FeaturedTitlesView\x12\x33\n\rallTitlesView\x18\x05 \x01(\x0b\x32\x1c.mangaplus_api.AllTitlesView\x12\x39\n\x10titleRankingView\x18\x06 \x01(\x0b\x32\x1f.mangaplus_api.TitleRankingView\x12\x41\n\x14subscribedTitlesView\x18\x07 \x01(\x0b\x32#.mangaplus_api.SubscribedTitlesView\x12\x37\n\x0ftitleDetailView\x18\x08 \x01(\x0b\x32\x1e.mangaplus_api.TitleDetailView\x12\x37\n\x0f\x63ommentListView\x18\t \x01(\x0b\x32\x1e.mangaplus_api.CommentListView\x12/\n\x0bmangaViewer\x18\n \x01(\x0b\x32\x1a.mangaplus_api.MangaViewer\x12?\n\x13profileSettingsView\x18\r \x01(\x0b\x32\".mangaplus_api.ProfileSettingsView\x12G\n\x17updateProfileResultView\x18\x0e \x01(\x0b\x32&.mangaplus_api.UpdateProfileResultView\x12I\n\x18serviceAnnouncementsView\x18\x0f \x01(\x0b\x32\'.mangaplus_api.ServiceAnnouncementsView\x12\x31\n\x0c\x66\x65\x65\x64\x62\x61\x63kView\x18\x11 \x01(\x0b\x32\x1b.mangaplus_api.FeedbackView\x12\x43\n\x15publisherNewsListView\x18\x12 \x01(\x0b\x32$.mangaplus_api.PublisherNewsListView\x12;\n\x11questionnaireView\x18\x13 \x01(\x0b\x32 .mangaplus_api.QuestionnaireView\x12\x39\n\x10titleUpdatedView\x18\x14 \x01(\x0b\x32\x1f.mangaplus_api.TitleUpdatedView\x12\x41\n\x14updatedTitleListView\x18\x16 \x01(\x0b\x32#.mangaplus_api.UpdatedTitleListView\x12?\n\x13\x61llTicketTitlesView\x18\x17 \x01(\x0b\x32\".mangaplus_api.AllTicketTitlesView\x12-\n\nhomeViewV3\x18\x18 \x01(\x0b\x32\x19.mangaplus_api.HomeViewV3\x12\x37\n\x0f\x61llTitlesViewV2\x18\x19 \x01(\x0b\x32\x1e.mangaplus_api.AllTitlesViewV2\x12\x35\n\x0esettingsViewV2\x18\x1a \x01(\x0b\x32\x1d.mangaplus_api.SettingsViewV2\x12:\n\x0ftitleListViewV2\x18\x1b \x01(\x0b\x32!.mangaplus_api.TitleUpdatedViewV2\x12\x33\n\rinitialViewV2\x18\x1c \x01(\x0b\x32\x1c.mangaplus_api.InitialViewV2\x12+\n\tlanguages\x18\x1d \x01(\x0b\x32\x18.mangaplus_api.Languages\x12\x33\n\rpushTokenView\x18  \x01(\x0b\x32\x1c.mangaplus_api.PushTokenView\x12;\n\x11\x61llFreeTitlesView\x18! \x01(\x0b\x32 .mangaplus_api.AllFreeTitlesView\x12/\n\x0blabeledView\x18\" \x01(\x0b\x32\x1a.mangaplus_api.LabeledView\x12-\n\nsearchView\x18# \x01(\x0b\x32\x19.mangaplus_api.SearchView\x12\x39\n\x10subscriptionView\x18$ \x01(\x0b\x32\x1f.mangaplus_api.SubscriptionView\x12=\n\x12titleRankingViewV2\x18% \x01(\x0b\x32!.mangaplus_api.TitleRankingViewV2\x12\x33\n\rwebHomeViewV4\x18& \x01(\x0b\x32\x1c.mangaplus_api.WebHomeViewV4\x12\x41\n\x14\x66\x65\x61turedTitlesViewV2\x18\' \x01(\x0b\x32#.mangaplus_api.FeaturedTitlesViewV2\x12/\n\x0bhistoryView\x18( \x01(\x0b\x32\x1a.mangaplus_api.HistoryView\x12\x45\n\x16\x64ownloadableImagesView\x18) \x01(\x0b\x32%.mangaplus_api.DownloadableImagesView\x12\x43\n\x15introduceSubscription\x18* \x01(\x0b\x32$.mangaplus_api.IntroduceSubscription\x12=\n\x12\x66\x61voriteTitlesView\x18+ \x01(\x0b\x32!.mangaplus_api.FavoriteTitlesView\x12\x33\n\rmpcStatusView\x18, \x01(\x0b\x32\x1c.mangaplus_api.MpcStatusView\x12-\n\nhomeViewV4\x18- \x01(\x0b\x32\x19.mangaplus_api.HomeViewV4\"\xfd\x06\n\x08\x44\x61taCase\x12\x10\n\x0c\x44\x41TA_NOT_SET\x10\x00\x12\x16\n\x12REGISTERATION_DATA\x10\x02\x12\x18\n\x14\x46\x45\x41TURED_TITLES_VIEW\x10\x04\x12\x13\n\x0f\x41LL_TITLES_VIEW\x10\x05\x12\x16\n\x12TITLE_RANKING_VIEW\x10\x06\x12\x1a\n\x16SUBSCRIBED_TITLES_VIEW\x10\x07\x12\x15\n\x11TITLE_DETAIL_VIEW\x10\x08\x12\x15\n\x11\x43OMMENT_LIST_VIEW\x10\t\x12\x10\n\x0cMANGA_VIEWER\x10\n\x12\x19\n\x15PROFILE_SETTINGS_VIEW\x10\r\x12\x1e\n\x1aUPDATE_PROFILE_RESULT_VIEW\x10\x0e\x12\x1e\n\x1aSERVICE_ANNOUNCEMENTS_VIEW\x10\x0f\x12\x11\n\rFEEDBACK_VIEW\x10\x11\x12\x1c\n\x18PUBLISHER_NEWS_LIST_VIEW\x10\x12\x12\x16\n\x12QUESTIONNAIRE_VIEW\x10\x13\x12\x16\n\x12TITLE_UPDATED_VIEW\x10\x14\x12\x1b\n\x17UPDATED_TITLE_LIST_VIEW\x10\x16\x12\x1a\n\x16\x41LL_TICKET_TITLES_VIEW\x10\x17\x12\x10\n\x0cHOME_VIEW_V3\x10\x18\x12\x16\n\x12\x41LL_TITLES_VIEW_V2\x10\x19\x12\x14\n\x10SETTINGS_VIEW_V2\x10\x1a\x12\x16\n\x12TITLE_LIST_VIEW_V2\x10\x1b\x12\x13\n\x0fINITIAL_VIEW_V2\x10\x1c\x12\x13\n\x0fPUSH_TOKEN_VIEW\x10 \x12\x18\n\x14\x41LL_FREE_TITLES_VIEW\x10!\x12\x10\n\x0cLABELED_VIEW\x10\"\x12\x0f\n\x0bSEARCH_VIEW\x10#\x12\x15\n\x11SUBSCRIPTION_VIEW\x10$\x12\x19\n\x15TITLE_RANKING_VIEW_V2\x10%\x12\x14\n\x10WEB_HOME_VIEW_V4\x10&\x12\x1b\n\x17\x46\x45\x41TURED_TITLES_VIEW_V2\x10\'\x12\x10\n\x0cHISTORY_VIEW\x10(\x12\x1c\n\x18\x44OWNLOADABLE_IMAGES_VIEW\x10)\x12\x1a\n\x16INTRODUCE_SUBSCRIPTION\x10*\x12\x18\n\x14\x46\x41VORITE_TITLES_VIEW\x10+\x12\x13\n\x0fMPC_STATUS_VIEW\x10,\x12\x10\n\x0cHOME_VIEW_V4\x10-\" \n\x03Tag\x12\x0b\n\x03tag\x18\x01 \x01(\t\x12\x0c\n\x04slug\x18\x02 \x01(\t\"\x88\x12\n\x0fTitleDetailView\x12#\n\x05title\x18\x01 \x01(\x0b\x32\x14.mangaplus_api.Title\x12\x15\n\rtitleImageUrl\x18\x02 \x01(\t\x12\x10\n\x08overview\x18\x03 \x01(\t\x12\x1a\n\x12\x62\x61\x63kgroundImageUrl\x18\x04 \x01(\t\x12\x15\n\rnextTimeStamp\x18\x05 \x01(\x03\x12\x14\n\x0cupdateTiming\x18\x06 \x01(\x05\x12 \n\x18viewingPeriodDescription\x18\x07 \x01(\t\x12\x19\n\x11nonAppearanceInfo\x18\x08 \x01(\t\x12\x30\n\x10\x66irstChapterList\x18\t \x03(\x0b\x32\x16.mangaplus_api.Chapter\x12/\n\x0flastChapterList\x18\n \x03(\x0b\x32\x16.mangaplus_api.Chapter\x12&\n\x07\x62\x61nners\x18\x0b \x03(\x0b\x32\x15.mangaplus_api.Banner\x12\x32\n\x14recommendedTitleList\x18\x0c \x03(\x0b\x32\x14.mangaplus_api.Title\x12\x1f\n\x03sns\x18\r \x01(\x0b\x32\x12.mangaplus_api.Sns\x12\x17\n\x0fisSimulReleased\x18\x0e \x01(\x08\x12\x14\n\x0cisSubscribed\x18\x0f \x01(\x08\x12\x35\n\x06rating\x18\x10 \x01(\x0e\x32%.mangaplus_api.TitleDetailView.Rating\x12\x1a\n\x12\x63haptersDescending\x18\x11 \x01(\x08\x12\x15\n\rnumberOfViews\x18\x12 \x01(\x05\x12\x44\n\x0epublisherItems\x18\x13 \x03(\x0b\x32,.mangaplus_api.TitleDetailView.PublisherItem\x12+\n\x0ctitleBanners\x18\x14 \x03(\x0b\x32\x15.mangaplus_api.Banner\x12/\n\x0buserTickets\x18\x15 \x01(\x0b\x32\x1a.mangaplus_api.UserTickets\x12\x31\n\x11ticketChapterList\x18\x16 \x03(\x0b\x32\x16.mangaplus_api.Chapter\x12-\n\x0fticketTitleList\x18\x17 \x03(\x0b\x32\x14.mangaplus_api.Title\x12\x1a\n\x12hasChaptersBetween\x18\x18 \x01(\x08\x12.\n\x0fpublisherBanner\x18\x19 \x01(\x0b\x32\x15.mangaplus_api.Banner\x12\x33\n\radvertisement\x18\x1a \x01(\x0b\x32\x1c.mangaplus_api.AdNetworkList\x12\x45\n\x0etitleLanguages\x18\x1b \x03(\x0b\x32-.mangaplus_api.TitleDetailView.TitleLanguages\x12\x45\n\x10\x63hapterListGroup\x18\x1c \x03(\x0b\x32+.mangaplus_api.TitleDetailView.ChapterGroup\x12\x39\n\x10\x66reeViewDialogue\x18\x1d \x01(\x0b\x32\x1f.mangaplus_api.FreeViewDialogue\x12\x12\n\nregionCode\x18\x1e \x01(\t\x12 \n\x04tags\x18\x1f \x03(\x0b\x32\x12.mangaplus_api.Tag\x12?\n\x0btitleLabels\x18  \x01(\x0b\x32*.mangaplus_api.TitleDetailView.TitleLabels\x12\x35\n\x10userSubscription\x18! \x01(\x0b\x32\x1b.mangaplus_api.Subscription\x12#\n\x05label\x18\" \x01(\x0b\x32\x14.mangaplus_api.Label\x12\x17\n\x0fisFirstTimeFree\x18# \x01(\x08\x12)\n\x08metaInfo\x18$ \x01(\x0b\x32\x17.mangaplus_api.MetaInfo\x12)\n\x0bratingPopup\x18% \x01(\x0b\x32\x14.mangaplus_api.Popup\x1aL\n\x0bTitleLabels\x12\x17\n\x0freleaseSchedule\x18\x01 \x01(\x05\x12\x12\n\nisSimulpub\x18\x02 \x01(\x08\x12\x10\n\x08planType\x18\x03 \x01(\t\x1ak\n\rPublisherItem\x12%\n\x06\x62\x61nner\x18\x01 \x01(\x0b\x32\x15.mangaplus_api.Banner\x12\x33\n\rpublisherNews\x18\x02 \x01(\x0b\x32\x1c.mangaplus_api.PublisherNews\x1aL\n\x0eTitleLanguages\x12\x0f\n\x07titleId\x18\x01 \x01(\x05\x12)\n\x08language\x18\x02 \x01(\x0e\x32\x17.mangaplus_api.Language\x1a\xb9\x01\n\x0c\x43hapterGroup\x12\x16\n\x0e\x63hapterNumbers\x18\x01 \x01(\t\x12\x30\n\x10\x66irstChapterList\x18\x02 \x03(\x0b\x32\x16.mangaplus_api.Chapter\x12.\n\x0emidChapterList\x18\x03 \x03(\x0b\x32\x16.mangaplus_api.Chapter\x12/\n\x0flastChapterList\x18\x04 \x03(\x0b\x32\x16.mangaplus_api.Chapter\"\x8d\x01\n\x0fReleaseSchedule\x12\x0c\n\x08\x44ISABLED\x10\x00\x12\x0c\n\x08\x45VERYDAY\x10\x01\x12\n\n\x06WEEKLY\x10\x02\x12\x0c\n\x08\x42IWEEKLY\x10\x03\x12\x0b\n\x07MONTHLY\x10\x04\x12\r\n\tBIMONTHLY\x10\x05\x12\x0e\n\nTRIMONTHLY\x10\x06\x12\t\n\x05OTHER\x10\x07\x12\r\n\tCOMPLETED\x10\x08\"\x86\x01\n\x0cUpdateTiming\x12\x11\n\rNOT_REGULARLY\x10\x00\x12\n\n\x06MONDAY\x10\x01\x12\x0b\n\x07TUESDAY\x10\x02\x12\r\n\tWEDNESDAY\x10\x03\x12\x0c\n\x08THURSDAY\x10\x04\x12\n\n\x06\x46RIDAY\x10\x05\x12\x0c\n\x08SATURDAY\x10\x06\x12\n\n\x06SUNDAY\x10\x07\x12\x07\n\x03\x44\x41Y\x10\x08\"8\n\x06Rating\x12\n\n\x06\x41LLAGE\x10\x00\x12\x08\n\x04TEEN\x10\x01\x12\x0c\n\x08TEENPLUS\x10\x02\x12\n\n\x06MATURE\x10\x03\"\xb2\x01\n\x0e\x41llTitlesGroup\x12\x10\n\x08theTitle\x18\x01 \x01(\t\x12$\n\x06titles\x18\x02 \x03(\x0b\x32\x14.mangaplus_api.Title\x12 \n\x04tags\x18\x03 \x03(\x0b\x32\x12.mangaplus_api.Tag\x12#\n\x05label\x18\x04 \x01(\x0b\x32\x14.mangaplus_api.Label\x12!\n\x19nextChapterStartTimestamp\x18\x05 \x01(\x03\"a\n\x11TitleRankingGroup\x12\x17\n\x0foriginalTitleId\x18\x01 \x01(\x05\x12$\n\x06titles\x18\x02 \x03(\x0b\x32\x14.mangaplus_api.Title\x12\r\n\x05score\x18\x03 \x01(\x05\"f\n\x11TitleUpdatedGroup\x12\x1d\n\x15updatedTitleTimestamp\x18\x01 \x01(\x03\x12\x32\n\x0blatestTitle\x18\x02 \x03(\x0b\x32\x1d.mangaplus_api.AllTitlesGroup\"L\n\x12LabeledTitlesGroup\x12\x10\n\x08theTitle\x18\x01 \x01(\t\x12$\n\x06titles\x18\x02 \x03(\x0b\x32\x14.mangaplus_api.Title\"d\n\x16TitleSubscriptionGroup\x12\x0c\n\x04plan\x18\x01 \x01(\t\x12$\n\x06titles\x18\x02 \x03(\x0b\x32\x14.mangaplus_api.Title\x12\x16\n\x0etitleCountText\x18\x03 \x01(\t\"`\n\tTitleList\x12\x10\n\x08listName\x18\x01 \x01(\t\x12,\n\x0e\x66\x65\x61turedTitles\x18\x02 \x03(\x0b\x32\x14.mangaplus_api.Title\x12\x13\n\x0b\x63ontainerId\x18\x03 \x01(\x05\"V\n\x0f\x43hapterPageList\x12\x10\n\x08listName\x18\x01 \x01(\t\x12\x31\n\x0c\x63hapterPages\x18\x02 \x03(\x0b\x32\x1b.mangaplus_api.ChapterPages\"\xa3\x01\n\x0c\x43hapterPages\x12\x13\n\x0b\x63ontainerId\x18\x01 \x01(\x05\x12\x11\n\tchapterId\x18\x02 \x01(\x05\x12\x0f\n\x07titleId\x18\x03 \x01(\x05\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0e\n\x06\x61uthor\x18\x05 \x01(\t\x12\x18\n\x10\x66\x61voriteImageUrl\x18\x06 \x01(\t\x12\"\n\x05pages\x18\x07 \x03(\x0b\x32\x13.mangaplus_api.Page\"\x80\x02\n\x05Title\x12\x0f\n\x07titleId\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06\x61uthor\x18\x03 \x01(\t\x12\x18\n\x10portraitImageUrl\x18\x04 \x01(\t\x12\x19\n\x11landscapeImageUrl\x18\x05 \x01(\t\x12\x11\n\tviewCount\x18\x06 \x01(\x05\x12)\n\x08language\x18\x07 \x01(\x0e\x32\x17.mangaplus_api.Language\x12;\n\x11titleUpdateStatus\x18\x08 \x01(\x0e\x32 .mangaplus_api.TitleUpdateStatus\x12\x18\n\x10\x66\x61voriteImageUrl\x18\t \x01(\t\"\xb8\x01\n\x0cUpdatedTitle\x12#\n\x05title\x18\x01 \x01(\x0b\x32\x14.mangaplus_api.Title\x12\x11\n\tchapterId\x18\x02 \x01(\x05\x12\x13\n\x0b\x63hapterName\x18\x03 \x01(\t\x12\x17\n\x0f\x63hapterSubTitle\x18\x04 \x01(\t\x12\x10\n\x08isLatest\x18\x05 \x01(\x08\x12\x16\n\x0eisVerticalOnly\x18\x06 \x01(\x08\x12\x18\n\x10isHorizontalOnly\x18\x07 \x01(\x08\"R\n\x0cTitleUpdated\x12#\n\x05title\x18\x01 \x01(\x0b\x32\x14.mangaplus_api.Title\x12\x1d\n\x15updatedTitleTimestamp\x18\x02 \x01(\t\"O\n\tFreeTitle\x12#\n\x05title\x18\x01 \x01(\x0b\x32\x14.mangaplus_api.Title\x12\x1d\n\x15updatedTitleTimestamp\x18\x02 \x01(\t\"j\n\x0cTicketTitles\x12#\n\x05title\x18\x01 \x01(\x0b\x32\x14.mangaplus_api.Title\x12\x1a\n\x12\x66irstTicketChapter\x18\x02 \x01(\x05\x12\x19\n\x11lastTicketChapter\x18\x03 \x01(\x05\"`\n\x11SubscribableTitle\x12#\n\x05title\x18\x01 \x01(\x0b\x32\x14.mangaplus_api.Title\x12\x10\n\x08isLatest\x18\x02 \x01(\x08\x12\x14\n\x0cisSubscribed\x18\x03 \x01(\x08\"r\n\x0f\x43omingSoonTitle\x12#\n\x05title\x18\x01 \x01(\x0b\x32\x14.mangaplus_api.Title\x12\x17\n\x0fnextChapterName\x18\x02 \x01(\t\x12!\n\x19nextChapterStartTimestamp\x18\x03 \x01(\x03\"\xb5\x01\n\x0eTitleHighlight\x12#\n\x05title\x18\x01 \x01(\x0b\x32\x14.mangaplus_api.Title\x12\x11\n\tchapterId\x18\x02 \x01(\x05\x12\x13\n\x0bpageUrlList\x18\x03 \x03(\t\x12\x11\n\tpageHight\x18\x04 \x01(\x05\x12\x11\n\tpageWidth\x18\x05 \x01(\x05\x12\x16\n\x0eisVerticalOnly\x18\x06 \x01(\x08\x12\x18\n\x10isHorizontalOnly\x18\x07 \x01(\x08\"8\n\x10TitleRankingView\x12$\n\x06titles\x18\x01 \x03(\x0b\x32\x14.mangaplus_api.Title\"\x95\x01\n\x12TitleRankingViewV2\x12-\n\x0erankingBanners\x18\x01 \x03(\x0b\x32\x15.mangaplus_api.Banner\x12\x18\n\x10updatedTimeStamp\x18\x02 \x01(\x03\x12\x36\n\x0crankedTitles\x18\x03 \x03(\x0b\x32 .mangaplus_api.TitleRankingGroup\"D\n\x10TitleUpdatedView\x12\x30\n\x0blatestTitle\x18\x01 \x03(\x0b\x32\x1b.mangaplus_api.TitleUpdated\"Q\n\x12TitleUpdatedViewV2\x12;\n\x11titleUpdatedGroup\x18\x01 \x03(\x0b\x32 .mangaplus_api.TitleUpdatedGroup\"\x9c\x01\n\x10TransitionAction\x12\x42\n\x06method\x18\x01 \x01(\x0e\x32\x32.mangaplus_api.TransitionAction.PresentationMethod\x12\x0b\n\x03url\x18\x02 \x01(\t\"7\n\x12PresentationMethod\x12\x08\n\x04PUSH\x10\x00\x12\t\n\x05MODAL\x10\x01\x12\x0c\n\x08\x45XTERNAL\x10\x02\"S\n\x11UpdatedTitleGroup\x12\x11\n\tgroupName\x18\x01 \x01(\t\x12+\n\x06titles\x18\x02 \x03(\x0b\x32\x1b.mangaplus_api.UpdatedTitle\"w\n\x13UpdatedTitleV2Group\x12\x11\n\tgroupName\x18\x01 \x01(\t\x12\x36\n\x0btitleGroups\x18\x02 \x03(\x0b\x32!.mangaplus_api.OriginalTitleGroup\x12\x15\n\rgroupNameDays\x18\x03 \x01(\x05\"\xd4\x01\n\x12OriginalTitleGroup\x12\x10\n\x08theTitle\x18\x01 \x01(\t\x12\x15\n\rchapterNumber\x18\x02 \x01(\t\x12+\n\x06titles\x18\x03 \x03(\x0b\x32\x1b.mangaplus_api.UpdatedTitle\x12\x11\n\tviewCount\x18\x04 \x01(\x05\x12;\n\x11titleUpdateStatus\x18\x05 \x01(\x0e\x32 .mangaplus_api.TitleUpdateStatus\x12\x18\n\x10\x63hapterStartTime\x18\x06 \x01(\x05\"H\n\x14UpdatedTitleListView\x12\x30\n\x06groups\x18\x01 \x03(\x0b\x32 .mangaplus_api.UpdatedTitleGroup\"\x8c\x01\n\x17UpdateProfileResultView\x12=\n\x06result\x18\x01 \x01(\x0e\x32-.mangaplus_api.UpdateProfileResultView.Result\"2\n\x06Result\x12\x0b\n\x07SUCCESS\x10\x00\x12\x0e\n\nDUPLICATED\x10\x01\x12\x0b\n\x07NG_WORD\x10\x02\"B\n\x0bUserTickets\x12\x16\n\x0e\x63urrentTickets\x18\x01 \x01(\x05\x12\x1b\n\x13nextTicketTimestamp\x18\x02 \x01(\x03\"\xc3\x02\n\rWebHomeViewV4\x12)\n\ntopBanners\x18\x01 \x03(\x0b\x32\x15.mangaplus_api.Banner\x12\x32\n\x06groups\x18\x02 \x03(\x0b\x32\".mangaplus_api.UpdatedTitleV2Group\x12\x36\n\x0crankedTitles\x18\x03 \x03(\x0b\x32 .mangaplus_api.TitleRankingGroup\x12#\n\x05popup\x18\x04 \x01(\x0b\x32\x14.mangaplus_api.Popup\x12\x34\n\x12\x66\x65\x61turedTitleLists\x18\x05 \x03(\x0b\x32\x18.mangaplus_api.TitleList\x12@\n\x14serviceAnnouncements\x18\x06 \x03(\x0b\x32\".mangaplus_api.ServiceAnnouncement*7\n\x15\x46irstTimeFreePlatform\x12\x0c\n\x08\x44ISABLED\x10\x00\x12\x07\n\x03WEB\x10\x01\x12\x07\n\x03\x41PP\x10\x02*\x94\x01\n\nLabelCodes\x12\x06\n\x02WJ\x10\x00\x12\x06\n\x02SQ\x10\x01\x12\x06\n\x02VJ\x10\x02\x12\x06\n\x02YJ\x10\x03\x12\n\n\x06J_PLUS\x10\x04\x12\x0b\n\x07REVIVAL\x10\x05\x12\x0c\n\x08\x43REATORS\x10\x06\x12\x07\n\x03MEE\x10\x07\x12\x07\n\x03TYJ\x10\x08\x12\n\n\x06OTHERS\x10\t\x12\x07\n\x03SKJ\x10\n\x12\x08\n\x04GIGA\x10\x0b\x12\x06\n\x02UJ\x10\x0c\x12\x06\n\x02\x44X\x10\r*\x93\x01\n\x08Language\x12\x0b\n\x07\x45NGLISH\x10\x00\x12\x0b\n\x07SPANISH\x10\x01\x12\n\n\x06\x46RENCH\x10\x02\x12\x0e\n\nINDONESIAN\x10\x03\x12\x11\n\rPORTUGUESE_BR\x10\x04\x12\x0b\n\x07RUSSIAN\x10\x05\x12\x08\n\x04THAI\x10\x06\x12\n\n\x06GERMAN\x10\x07\x12\x0b\n\x07ITALIAN\x10\x08\x12\x0e\n\nVIETNAMESE\x10\t*:\n\x0eRankingTabType\x12\x0b\n\x07HOTTEST\x10\x00\x12\x0c\n\x08TRENDING\x10\x01\x12\r\n\tCOMPLETED\x10\x02*a\n\x11TitleUpdateStatus\x12\x08\n\x04NONE\x10\x00\x12\x07\n\x03NEW\x10\x01\x12\x06\n\x02UP\x10\x02\x12\r\n\tREEDITION\x10\x03\x12\x13\n\x0f\x43REATORS_STATUS\x10\x04\x12\r\n\tOUR_PICKS\x10\x05\x42\x18\n\x16jp.co.comic.jump.protob\x06proto3')

_FIRSTTIMEFREEPLATFORM = DESCRIPTOR.enum_types_by_name['FirstTimeFreePlatform']
FirstTimeFreePlatform = enum_type_wrapper.EnumTypeWrapper(_FIRSTTIMEFREEPLATFORM)
_LABELCODES = DESCRIPTOR.enum_types_by_name['LabelCodes']
LabelCodes = enum_type_wrapper.EnumTypeWrapper(_LABELCODES)
_LANGUAGE = DESCRIPTOR.enum_types_by_name['Language']
Language = enum_type_wrapper.EnumTypeWrapper(_LANGUAGE)
_RANKINGTABTYPE = DESCRIPTOR.enum_types_by_name['RankingTabType']
RankingTabType = enum_type_wrapper.EnumTypeWrapper(_RANKINGTABTYPE)
_TITLEUPDATESTATUS = DESCRIPTOR.enum_types_by_name['TitleUpdateStatus']
TitleUpdateStatus = enum_type_wrapper.EnumTypeWrapper(_TITLEUPDATESTATUS)
DISABLED = 0
WEB = 1
APP = 2
WJ = 0
SQ = 1
VJ = 2
YJ = 3
J_PLUS = 4
REVIVAL = 5
CREATORS = 6
MEE = 7
TYJ = 8
OTHERS = 9
SKJ = 10
GIGA = 11
UJ = 12
DX = 13
ENGLISH = 0
SPANISH = 1
FRENCH = 2
INDONESIAN = 3
PORTUGUESE_BR = 4
RUSSIAN = 5
THAI = 6
GERMAN = 7
ITALIAN = 8
VIETNAMESE = 9
HOTTEST = 0
TRENDING = 1
COMPLETED = 2
NONE = 0
NEW = 1
UP = 2
REEDITION = 3
CREATORS_STATUS = 4
OUR_PICKS = 5


_ADNETWORKLIST = DESCRIPTOR.message_types_by_name['AdNetworkList']
_ADREWARDNETWORKLIST = DESCRIPTOR.message_types_by_name['AdRewardNetworkList']
_ADNETWORK = DESCRIPTOR.message_types_by_name['AdNetwork']
_ADNETWORK_FACEBOOK = _ADNETWORK.nested_types_by_name['Facebook']
_ADNETWORK_ADMOB = _ADNETWORK.nested_types_by_name['Admob']
_ADNETWORK_ADSENSE = _ADNETWORK.nested_types_by_name['Adsense']
_ADNETWORK_APPLOVIN = _ADNETWORK.nested_types_by_name['Applovin']
_ADNETWORK_MOPUB = _ADNETWORK.nested_types_by_name['Mopub']
_ADNETWORK_APPLOVINMAX = _ADNETWORK.nested_types_by_name['ApplovinMax']
_ALLFREETITLESVIEW = DESCRIPTOR.message_types_by_name['AllFreeTitlesView']
_ALLTICKETTITLESVIEW = DESCRIPTOR.message_types_by_name['AllTicketTitlesView']
_ALLTITLESVIEW = DESCRIPTOR.message_types_by_name['AllTitlesView']
_ALLTITLESVIEWV2 = DESCRIPTOR.message_types_by_name['AllTitlesViewV2']
_BANNER = DESCRIPTOR.message_types_by_name['Banner']
_CHAPTER = DESCRIPTOR.message_types_by_name['Chapter']
_COMMENTICON = DESCRIPTOR.message_types_by_name['CommentIcon']
_COMMENTLISTVIEW = DESCRIPTOR.message_types_by_name['CommentListView']
_COMMENTLISTVIEW_TITLEDETAILCOMMENT = _COMMENTLISTVIEW.nested_types_by_name['TitleDetailComment']
_COMMENT = DESCRIPTOR.message_types_by_name['Comment']
_FREEVIEWDIALOGUE = DESCRIPTOR.message_types_by_name['FreeViewDialogue']
_DOWNLOADABLEIMAGESVIEW = DESCRIPTOR.message_types_by_name['DownloadableImagesView']
_DOWNLOADABLEIMAGEGROUP = DESCRIPTOR.message_types_by_name['DownloadableImageGroup']
_ERRORRESULT = DESCRIPTOR.message_types_by_name['ErrorResult']
_FAVORITETITLESVIEW = DESCRIPTOR.message_types_by_name['FavoriteTitlesView']
_FAVORITETITLEGROUP = DESCRIPTOR.message_types_by_name['FavoriteTitleGroup']
_FEATUREDTITLESVIEW = DESCRIPTOR.message_types_by_name['FeaturedTitlesView']
_FEATUREDTITLESVIEW_CONTENTS = _FEATUREDTITLESVIEW.nested_types_by_name['Contents']
_FEATUREDTITLESVIEWV2 = DESCRIPTOR.message_types_by_name['FeaturedTitlesViewV2']
_FEATUREDTITLESVIEWV2_CONTENTS = _FEATUREDTITLESVIEWV2.nested_types_by_name['Contents']
_FEEDBACK = DESCRIPTOR.message_types_by_name['Feedback']
_FEEDBACKVIEW = DESCRIPTOR.message_types_by_name['FeedbackView']
_HISTORYVIEW = DESCRIPTOR.message_types_by_name['HistoryView']
_HOMEVIEWV3 = DESCRIPTOR.message_types_by_name['HomeViewV3']
_HOMEVIEWV4 = DESCRIPTOR.message_types_by_name['HomeViewV4']
_HOMEVIEWV4_SECTIONS = _HOMEVIEWV4.nested_types_by_name['Sections']
_HOMEVIEWV4_WEEKLYSECTION = _HOMEVIEWV4.nested_types_by_name['WeeklySection']
_HOMEVIEWV4_WEEKLYSECTION_WEEKLYCONTENT = _HOMEVIEWV4_WEEKLYSECTION.nested_types_by_name['WeeklyContent']
_HOMEVIEWV4_WEEKLYSECTION_CONTENTITEM = _HOMEVIEWV4_WEEKLYSECTION.nested_types_by_name['ContentItem']
_HOMEVIEWV4_WEEKLYSECTION_MVBANNER = _HOMEVIEWV4_WEEKLYSECTION.nested_types_by_name['MVBanner']
_HOMEVIEWV4_WEEKLYSECTION_TITLEGROUP = _HOMEVIEWV4_WEEKLYSECTION.nested_types_by_name['TitleGroup']
_HOMEVIEWV4_WEEKLYSECTION_CAROUSELBANNER = _HOMEVIEWV4_WEEKLYSECTION.nested_types_by_name['CarouselBanner']
_HOMEVIEWV4_WEEKLYSECTION_MINORLANGUAGEBANNER = _HOMEVIEWV4_WEEKLYSECTION.nested_types_by_name['MinorLanguageBanner']
_HOMEVIEWV4_RANKINGSECTION = _HOMEVIEWV4.nested_types_by_name['RankingSection']
_HOMEVIEWV4_RANKINGSECTION_RANKINGTAB = _HOMEVIEWV4_RANKINGSECTION.nested_types_by_name['RankingTab']
_HOMEVIEWV4_PREVIEWSECTION = _HOMEVIEWV4.nested_types_by_name['PreviewSection']
_HOMEVIEWV4_PREVIEWSECTION_PREVIEWTAB = _HOMEVIEWV4_PREVIEWSECTION.nested_types_by_name['PreviewTab']
_HOMEVIEWV4_TITLELISTSECTION = _HOMEVIEWV4.nested_types_by_name['TitleListSection']
_HOMEVIEWV4_BANNERSECTION = _HOMEVIEWV4.nested_types_by_name['BannerSection']
_INITIALVIEWV2 = DESCRIPTOR.message_types_by_name['InitialViewV2']
_INTRODUCESUBSCRIPTION = DESCRIPTOR.message_types_by_name['IntroduceSubscription']
_LABELEDVIEW = DESCRIPTOR.message_types_by_name['LabeledView']
_LABEL = DESCRIPTOR.message_types_by_name['Label']
_LANGUAGES = DESCRIPTOR.message_types_by_name['Languages']
_AVAILABLELANGUAGES = DESCRIPTOR.message_types_by_name['AvailableLanguages']
_MANGAVIEWER = DESCRIPTOR.message_types_by_name['MangaViewer']
_MANGAVIEWER_TITLEAVAILABLELANGUAGES = _MANGAVIEWER.nested_types_by_name['TitleAvailableLanguages']
_METAINFO = DESCRIPTOR.message_types_by_name['MetaInfo']
_MPCSTATUSVIEW = DESCRIPTOR.message_types_by_name['MpcStatusView']
_PAGE = DESCRIPTOR.message_types_by_name['Page']
_PAGE_MANGAPAGE = _PAGE.nested_types_by_name['MangaPage']
_PAGE_LASTPAGE = _PAGE.nested_types_by_name['LastPage']
_PAGE_BANNERLIST = _PAGE.nested_types_by_name['BannerList']
_POPUP = DESCRIPTOR.message_types_by_name['Popup']
_POPUP_OSDEFAULT = _POPUP.nested_types_by_name['OSDefault']
_POPUP_APPDEFAULT = _POPUP.nested_types_by_name['AppDefault']
_POPUP_ONEIMAGE = _POPUP.nested_types_by_name['OneImage']
_POPUP_BUTTON = _POPUP.nested_types_by_name['Button']
_MOVIEREWARD = DESCRIPTOR.message_types_by_name['MovieReward']
_PROFILESETTINGSVIEW = DESCRIPTOR.message_types_by_name['ProfileSettingsView']
_PUBLISHERNEWSLISTVIEW = DESCRIPTOR.message_types_by_name['PublisherNewsListView']
_PUBLISHERNEWS = DESCRIPTOR.message_types_by_name['PublisherNews']
_PUSHTOKENVIEW = DESCRIPTOR.message_types_by_name['PushTokenView']
_QUESTIONNAIRE = DESCRIPTOR.message_types_by_name['Questionnaire']
_QUESTIONNAIREVIEW = DESCRIPTOR.message_types_by_name['QuestionnaireView']
_REGISTRATIONDATA = DESCRIPTOR.message_types_by_name['RegistrationData']
_RESPONSE = DESCRIPTOR.message_types_by_name['Response']
_SEARCHVIEW = DESCRIPTOR.message_types_by_name['SearchView']
_SEARCHVIEW_CONTENTS = _SEARCHVIEW.nested_types_by_name['Contents']
_SERVICEANNOUNCEMENT = DESCRIPTOR.message_types_by_name['ServiceAnnouncement']
_SERVICEANNOUNCEMENTSVIEW = DESCRIPTOR.message_types_by_name['ServiceAnnouncementsView']
_SETTINGSVIEW = DESCRIPTOR.message_types_by_name['SettingsView']
_SETTINGSVIEWV2 = DESCRIPTOR.message_types_by_name['SettingsViewV2']
_CUSTOMCODEDIALOGUE = DESCRIPTOR.message_types_by_name['CustomCodeDialogue']
_SNS = DESCRIPTOR.message_types_by_name['Sns']
_SUBSCRIBEDTITLESVIEW = DESCRIPTOR.message_types_by_name['SubscribedTitlesView']
_IOSSUBSCRIPTIONOFFER = DESCRIPTOR.message_types_by_name['IosSubscriptionOffer']
_ANDROIDSUBSCRIPTIONOFFERTAGS = DESCRIPTOR.message_types_by_name['AndroidSubscriptionOfferTags']
_SUBSCRIPTION = DESCRIPTOR.message_types_by_name['Subscription']
_PLANTYPE = DESCRIPTOR.message_types_by_name['PlanType']
_SUBSCRIPTIONVIEW = DESCRIPTOR.message_types_by_name['SubscriptionView']
_SUBSCRIPTIONPLANBOXDESCRIPTION = DESCRIPTOR.message_types_by_name['SubscriptionPlanBoxDescription']
_SUBSCRIPTIONNOTE = DESCRIPTOR.message_types_by_name['SubscriptionNote']
_SUCCESSRESULT = DESCRIPTOR.message_types_by_name['SuccessResult']
_TAG = DESCRIPTOR.message_types_by_name['Tag']
_TITLEDETAILVIEW = DESCRIPTOR.message_types_by_name['TitleDetailView']
_TITLEDETAILVIEW_TITLELABELS = _TITLEDETAILVIEW.nested_types_by_name['TitleLabels']
_TITLEDETAILVIEW_PUBLISHERITEM = _TITLEDETAILVIEW.nested_types_by_name['PublisherItem']
_TITLEDETAILVIEW_TITLELANGUAGES = _TITLEDETAILVIEW.nested_types_by_name['TitleLanguages']
_TITLEDETAILVIEW_CHAPTERGROUP = _TITLEDETAILVIEW.nested_types_by_name['ChapterGroup']
_ALLTITLESGROUP = DESCRIPTOR.message_types_by_name['AllTitlesGroup']
_TITLERANKINGGROUP = DESCRIPTOR.message_types_by_name['TitleRankingGroup']
_TITLEUPDATEDGROUP = DESCRIPTOR.message_types_by_name['TitleUpdatedGroup']
_LABELEDTITLESGROUP = DESCRIPTOR.message_types_by_name['LabeledTitlesGroup']
_TITLESUBSCRIPTIONGROUP = DESCRIPTOR.message_types_by_name['TitleSubscriptionGroup']
_TITLELIST = DESCRIPTOR.message_types_by_name['TitleList']
_CHAPTERPAGELIST = DESCRIPTOR.message_types_by_name['ChapterPageList']
_CHAPTERPAGES = DESCRIPTOR.message_types_by_name['ChapterPages']
_TITLE = DESCRIPTOR.message_types_by_name['Title']
_UPDATEDTITLE = DESCRIPTOR.message_types_by_name['UpdatedTitle']
_TITLEUPDATED = DESCRIPTOR.message_types_by_name['TitleUpdated']
_FREETITLE = DESCRIPTOR.message_types_by_name['FreeTitle']
_TICKETTITLES = DESCRIPTOR.message_types_by_name['TicketTitles']
_SUBSCRIBABLETITLE = DESCRIPTOR.message_types_by_name['SubscribableTitle']
_COMINGSOONTITLE = DESCRIPTOR.message_types_by_name['ComingSoonTitle']
_TITLEHIGHLIGHT = DESCRIPTOR.message_types_by_name['TitleHighlight']
_TITLERANKINGVIEW = DESCRIPTOR.message_types_by_name['TitleRankingView']
_TITLERANKINGVIEWV2 = DESCRIPTOR.message_types_by_name['TitleRankingViewV2']
_TITLEUPDATEDVIEW = DESCRIPTOR.message_types_by_name['TitleUpdatedView']
_TITLEUPDATEDVIEWV2 = DESCRIPTOR.message_types_by_name['TitleUpdatedViewV2']
_TRANSITIONACTION = DESCRIPTOR.message_types_by_name['TransitionAction']
_UPDATEDTITLEGROUP = DESCRIPTOR.message_types_by_name['UpdatedTitleGroup']
_UPDATEDTITLEV2GROUP = DESCRIPTOR.message_types_by_name['UpdatedTitleV2Group']
_ORIGINALTITLEGROUP = DESCRIPTOR.message_types_by_name['OriginalTitleGroup']
_UPDATEDTITLELISTVIEW = DESCRIPTOR.message_types_by_name['UpdatedTitleListView']
_UPDATEPROFILERESULTVIEW = DESCRIPTOR.message_types_by_name['UpdateProfileResultView']
_USERTICKETS = DESCRIPTOR.message_types_by_name['UserTickets']
_WEBHOMEVIEWV4 = DESCRIPTOR.message_types_by_name['WebHomeViewV4']
_ADNETWORK_ADTYPE = _ADNETWORK.enum_types_by_name['AdType']
_ADNETWORK_NETWORKCASE = _ADNETWORK.enum_types_by_name['NetworkCase']
_ERRORRESULT_ACTION = _ERRORRESULT.enum_types_by_name['Action']
_FEATUREDTITLESVIEW_CONTENTS_DATACASE = _FEATUREDTITLESVIEW_CONTENTS.enum_types_by_name['DataCase']
_FEEDBACK_RESPONSETYPE = _FEEDBACK.enum_types_by_name['ResponseType']
_HOMEVIEWV4_SECTIONS_SECTIONCASE = _HOMEVIEWV4_SECTIONS.enum_types_by_name['SectionCase']
_HOMEVIEWV4_WEEKLYSECTION_CONTENTITEM_CONTENTCASE = _HOMEVIEWV4_WEEKLYSECTION_CONTENTITEM.enum_types_by_name['ContentCase']
_PAGE_CHAPTERTYPE = _PAGE.enum_types_by_name['ChapterType']
_PAGE_PAGETYPE = _PAGE.enum_types_by_name['PageType']
_PAGE_DATACASE = _PAGE.enum_types_by_name['DataCase']
_POPUP_POPUPCASE = _POPUP.enum_types_by_name['PopupCase']
_RESPONSE_RESULTCASE = _RESPONSE.enum_types_by_name['ResultCase']
_IOSSUBSCRIPTIONOFFER_OFFERTYPE = _IOSSUBSCRIPTIONOFFER.enum_types_by_name['OfferType']
_SUCCESSRESULT_DATACASE = _SUCCESSRESULT.enum_types_by_name['DataCase']
_TITLEDETAILVIEW_RELEASESCHEDULE = _TITLEDETAILVIEW.enum_types_by_name['ReleaseSchedule']
_TITLEDETAILVIEW_UPDATETIMING = _TITLEDETAILVIEW.enum_types_by_name['UpdateTiming']
_TITLEDETAILVIEW_RATING = _TITLEDETAILVIEW.enum_types_by_name['Rating']
_TRANSITIONACTION_PRESENTATIONMETHOD = _TRANSITIONACTION.enum_types_by_name['PresentationMethod']
_UPDATEPROFILERESULTVIEW_RESULT = _UPDATEPROFILERESULTVIEW.enum_types_by_name['Result']
AdNetworkList = _reflection.GeneratedProtocolMessageType('AdNetworkList', (_message.Message,), {
  'DESCRIPTOR' : _ADNETWORKLIST,
  '__module__' : 'mangaplus_api_pb2'
  # @@protoc_insertion_point(class_scope:mangaplus_api.AdNetworkList)
  })
_sym_db.RegisterMessage(AdNetworkList)

AdRewardNetworkList = _reflection.GeneratedProtocolMessageType('AdRewardNetworkList', (_message.Message,), {
  'DESCRIPTOR' : _ADREWARDNETWORKLIST,
  '__module__' : 'mangaplus_api_pb2'
  # @@protoc_insertion_point(class_scope:mangaplus_api.AdRewardNetworkList)
  })
_sym_db.RegisterMessage(AdRewardNetworkList)

AdNetwork = _reflection.GeneratedProtocolMessageType('AdNetwork', (_message.Message,), {

  'Facebook' : _reflection.GeneratedProtocolMessageType('Facebook', (_message.Message,), {
    'DESCRIPTOR' : _ADNETWORK_FACEBOOK,
    '__module__' : 'mangaplus_api_pb2'
    # @@protoc_insertion_point(class_scope:mangaplus_api.AdNetwork.Facebook)
    })
  ,

  'Admob' : _reflection.GeneratedProtocolMessageType('Admob', (_message.Message,), {
    'DESCRIPTOR' : _ADNETWORK_ADMOB,
    '__module__' : 'mangaplus_api_pb2'
    # @@protoc_insertion_point(class_scope:mangaplus_api.AdNetwork.Admob)
    })
  ,

  'Adsense' : _reflection.GeneratedProtocolMessageType('Adsense', (_message.Message,), {
    'DESCRIPTOR' : _ADNETWORK_ADSENSE,
    '__module__' : 'mangaplus_api_pb2'
    # @@protoc_insertion_point(class_scope:mangaplus_api.AdNetwork.Adsense)
    })
  ,

  'Applovin' : _reflection.GeneratedProtocolMessageType('Applovin', (_message.Message,), {
    'DESCRIPTOR' : _ADNETWORK_APPLOVIN,
    '__module__' : 'mangaplus_api_pb2'
    # @@protoc_insertion_point(class_scope:mangaplus_api.AdNetwork.Applovin)
    })
  ,

  'Mopub' : _reflection.GeneratedProtocolMessageType('Mopub', (_message.Message,), {
    'DESCRIPTOR' : _ADNETWORK_MOPUB,
    '__module__' : 'mangaplus_api_pb2'
    # @@protoc_insertion_point(class_scope:mangaplus_api.AdNetwork.Mopub)
    })
  ,

  'ApplovinMax' : _reflection.GeneratedProtocolMessageType('ApplovinMax', (_message.Message,), {
    'DESCRIPTOR' : _ADNETWORK_APPLOVINMAX,
    '__module__' : 'mangaplus_api_pb2'
    # @@protoc_insertion_point(class_scope:mangaplus_api.AdNetwork.ApplovinMax)
    })
  ,
  'DESCRIPTOR' : _ADNETWORK,
  '__module__' : 'mangaplus_api_pb2'
  # @@protoc_insertion_point(class_scope:mangaplus_api.AdNetwork)
  })
_sym_db.RegisterMessage(AdNetwork)
_sym_db.RegisterMessage(AdNetwork.Facebook)
_sym_db.RegisterMessage(AdNetwork.Admob)
_sym_db.RegisterMessage(AdNetwork.Adsense)
_sym_db.RegisterMessage(AdNetwork.Applovin)
_sym_db.RegisterMessage(AdNetwork.Mopub)
_sym_db.RegisterMessage(AdNetwork.ApplovinMax)

AllFreeTitlesView = _reflection.GeneratedProtocolMessageType('AllFreeTitlesView', (_message.Message,), {
  'DESCRIPTOR' : _ALLFREETITLESVIEW,
  '__module__' : 'mangaplus_api_pb2'
  # @@protoc_insertion_point(class_scope:mangaplus_api.AllFreeTitlesView)
  })
_sym_db.RegisterMessage(AllFreeTitlesView)

AllTicketTitlesView = _reflection.GeneratedProtocolMessageType('AllTicketTitlesView', (_message.Message,), {
  'DESCRIPTOR' : _ALLTICKETTITLESVIEW,
  '__module__' : 'mangaplus_api_pb2'
  # @@protoc_insertion_point(class_scope:mangaplus_api.AllTicketTitlesView)
  })
_sym_db.RegisterMessage(AllTicketTitlesView)

AllTitlesView = _reflection.GeneratedProtocolMessageType('AllTitlesView', (_message.Message,), {
  'DESCRIPTOR' : _ALLTITLESVIEW,
  '__module__' : 'mangaplus_api_pb2'
  # @@protoc_insertion_point(class_scope:mangaplus_api.AllTitlesView)
  })
_sym_db.RegisterMessage(AllTitlesView)

AllTitlesViewV2 = _reflection.GeneratedProtocolMessageType('AllTitlesViewV2', (_message.Message,), {
  'DESCRIPTOR' : _ALLTITLESVIEWV2,
  '__module__' : 'mangaplus_api_pb2'
  # @@protoc_insertion_point(class_scope:mangaplus_api.AllTitlesViewV2)
  })
_sym_db.RegisterMessage(AllTitlesViewV2)

Banner = _reflection.GeneratedProtocolMessageType('Banner', (_message.Message,), {
  'DESCRIPTOR' : _BANNER,
  '__module__' : 'mangaplus_api_pb2'
  # @@protoc_insertion_point(class_scope:mangaplus_api.Banner)
  })
_sym_db.RegisterMessage(Banner)

Chapter = _reflection.GeneratedProtocolMessageType('Chapter', (_message.Message,), {
  'DESCRIPTOR' : _CHAPTER,
  '__module__' : 'mangaplus_api_pb2'
  # @@protoc_insertion_point(class_scope:mangaplus_api.Chapter)
  })
_sym_db.RegisterMessage(Chapter)

CommentIcon = _reflection.GeneratedProtocolMessageType('CommentIcon', (_message.Message,), {
  'DESCRIPTOR' : _COMMENTICON,
  '__module__' : 'mangaplus_api_pb2'
  # @@protoc_insertion_point(class_scope:mangaplus_api.CommentIcon)
  })
_sym_db.RegisterMessage(CommentIcon)

CommentListView = _reflection.GeneratedProtocolMessageType('CommentListView', (_message.Message,), {

  'TitleDetailComment' : _reflection.GeneratedProtocolMessageType('TitleDetailComment', (_message.Message,), {
    'DESCRIPTOR' : _COMMENTLISTVIEW_TITLEDETAILCOMMENT,
    '__module__' : 'mangaplus_api_pb2'
    # @@protoc_insertion_point(class_scope:mangaplus_api.CommentListView.TitleDetailComment)
    })
  ,
  'DESCRIPTOR' : _COMMENTLISTVIEW,
  '__module__' : 'mangaplus_api_pb2'
  # @@protoc_insertion_point(class_scope:mangaplus_api.CommentListView)
  })
_sym_db.RegisterMessage(CommentListView)
_sym_db.RegisterMessage(CommentListView.TitleDetailComment)

Comment = _reflection.GeneratedProtocolMessageType('Comment', (_message.Message,), {
  'DESCRIPTOR' : _COMMENT,
  '__module__' : 'mangaplus_api_pb2'
  # @@protoc_insertion_point(class_scope:mangaplus_api.Comment)
  })
_sym_db.RegisterMessage(Comment)

FreeViewDialogue = _reflection.GeneratedProtocolMessageType('FreeViewDialogue', (_message.Message,), {
  'DESCRIPTOR' : _FREEVIEWDIALOGUE,
  '__module__' : 'mangaplus_api_pb2'
  # @@protoc_insertion_point(class_scope:mangaplus_api.FreeViewDialogue)
  })
_sym_db.RegisterMessage(FreeViewDialogue)

DownloadableImagesView = _reflection.GeneratedProtocolMessageType('DownloadableImagesView', (_message.Message,), {
  'DESCRIPTOR' : _DOWNLOADABLEIMAGESVIEW,
  '__module__' : 'mangaplus_api_pb2'
  # @@protoc_insertion_point(class_scope:mangaplus_api.DownloadableImagesView)
  })
_sym_db.RegisterMessage(DownloadableImagesView)

DownloadableImageGroup = _reflection.GeneratedProtocolMessageType('DownloadableImageGroup', (_message.Message,), {
  'DESCRIPTOR' : _DOWNLOADABLEIMAGEGROUP,
  '__module__' : 'mangaplus_api_pb2'
  # @@protoc_insertion_point(class_scope:mangaplus_api.DownloadableImageGroup)
  })
_sym_db.RegisterMessage(DownloadableImageGroup)

ErrorResult = _reflection.GeneratedProtocolMessageType('ErrorResult', (_message.Message,), {
  'DESCRIPTOR' : _ERRORRESULT,
  '__module__' : 'mangaplus_api_pb2'
  # @@protoc_insertion_point(class_scope:mangaplus_api.ErrorResult)
  })
_sym_db.RegisterMessage(ErrorResult)

FavoriteTitlesView = _reflection.GeneratedProtocolMessageType('FavoriteTitlesView', (_message.Message,), {
  'DESCRIPTOR' : _FAVORITETITLESVIEW,
  '__module__' : 'mangaplus_api_pb2'
  # @@protoc_insertion_point(class_scope:mangaplus_api.FavoriteTitlesView)
  })
_sym_db.RegisterMessage(FavoriteTitlesView)

FavoriteTitleGroup = _reflection.GeneratedProtocolMessageType('FavoriteTitleGroup', (_message.Message,), {
  'DESCRIPTOR' : _FAVORITETITLEGROUP,
  '__module__' : 'mangaplus_api_pb2'
  # @@protoc_insertion_point(class_scope:mangaplus_api.FavoriteTitleGroup)
  })
_sym_db.RegisterMessage(FavoriteTitleGroup)

FeaturedTitlesView = _reflection.GeneratedProtocolMessageType('FeaturedTitlesView', (_message.Message,), {

  'Contents' : _reflection.GeneratedProtocolMessageType('Contents', (_message.Message,), {
    'DESCRIPTOR' : _FEATUREDTITLESVIEW_CONTENTS,
    '__module__' : 'mangaplus_api_pb2'
    # @@protoc_insertion_point(class_scope:mangaplus_api.FeaturedTitlesView.Contents)
    })
  ,
  'DESCRIPTOR' : _FEATUREDTITLESVIEW,
  '__module__' : 'mangaplus_api_pb2'
  # @@protoc_insertion_point(class_scope:mangaplus_api.FeaturedTitlesView)
  })
_sym_db.RegisterMessage(FeaturedTitlesView)
_sym_db.RegisterMessage(FeaturedTitlesView.Contents)

FeaturedTitlesViewV2 = _reflection.GeneratedProtocolMessageType('FeaturedTitlesViewV2', (_message.Message,), {

  'Contents' : _reflection.GeneratedProtocolMessageType('Contents', (_message.Message,), {
    'DESCRIPTOR' : _FEATUREDTITLESVIEWV2_CONTENTS,
    '__module__' : 'mangaplus_api_pb2'
    # @@protoc_insertion_point(class_scope:mangaplus_api.FeaturedTitlesViewV2.Contents)
    })
  ,
  'DESCRIPTOR' : _FEATUREDTITLESVIEWV2,
  '__module__' : 'mangaplus_api_pb2'
  # @@protoc_insertion_point(class_scope:mangaplus_api.FeaturedTitlesViewV2)
  })
_sym_db.RegisterMessage(FeaturedTitlesViewV2)
_sym_db.RegisterMessage(FeaturedTitlesViewV2.Contents)

Feedback = _reflection.GeneratedProtocolMessageType('Feedback', (_message.Message,), {
  'DESCRIPTOR' : _FEEDBACK,
  '__module__' : 'mangaplus_api_pb2'
  # @@protoc_insertion_point(class_scope:mangaplus_api.Feedback)
  })
_sym_db.RegisterMessage(Feedback)

FeedbackView = _reflection.GeneratedProtocolMessageType('FeedbackView', (_message.Message,), {
  'DESCRIPTOR' : _FEEDBACKVIEW,
  '__module__' : 'mangaplus_api_pb2'
  # @@protoc_insertion_point(class_scope:mangaplus_api.FeedbackView)
  })
_sym_db.RegisterMessage(FeedbackView)

HistoryView = _reflection.GeneratedProtocolMessageType('HistoryView', (_message.Message,), {
  'DESCRIPTOR' : _HISTORYVIEW,
  '__module__' : 'mangaplus_api_pb2'
  # @@protoc_insertion_point(class_scope:mangaplus_api.HistoryView)
  })
_sym_db.RegisterMessage(HistoryView)

HomeViewV3 = _reflection.GeneratedProtocolMessageType('HomeViewV3', (_message.Message,), {
  'DESCRIPTOR' : _HOMEVIEWV3,
  '__module__' : 'mangaplus_api_pb2'
  # @@protoc_insertion_point(class_scope:mangaplus_api.HomeViewV3)
  })
_sym_db.RegisterMessage(HomeViewV3)

HomeViewV4 = _reflection.GeneratedProtocolMessageType('HomeViewV4', (_message.Message,), {

  'Sections' : _reflection.GeneratedProtocolMessageType('Sections', (_message.Message,), {
    'DESCRIPTOR' : _HOMEVIEWV4_SECTIONS,
    '__module__' : 'mangaplus_api_pb2'
    # @@protoc_insertion_point(class_scope:mangaplus_api.HomeViewV4.Sections)
    })
  ,

  'WeeklySection' : _reflection.GeneratedProtocolMessageType('WeeklySection', (_message.Message,), {

    'WeeklyContent' : _reflection.GeneratedProtocolMessageType('WeeklyContent', (_message.Message,), {
      'DESCRIPTOR' : _HOMEVIEWV4_WEEKLYSECTION_WEEKLYCONTENT,
      '__module__' : 'mangaplus_api_pb2'
      # @@protoc_insertion_point(class_scope:mangaplus_api.HomeViewV4.WeeklySection.WeeklyContent)
      })
    ,

    'ContentItem' : _reflection.GeneratedProtocolMessageType('ContentItem', (_message.Message,), {
      'DESCRIPTOR' : _HOMEVIEWV4_WEEKLYSECTION_CONTENTITEM,
      '__module__' : 'mangaplus_api_pb2'
      # @@protoc_insertion_point(class_scope:mangaplus_api.HomeViewV4.WeeklySection.ContentItem)
      })
    ,

    'MVBanner' : _reflection.GeneratedProtocolMessageType('MVBanner', (_message.Message,), {
      'DESCRIPTOR' : _HOMEVIEWV4_WEEKLYSECTION_MVBANNER,
      '__module__' : 'mangaplus_api_pb2'
      # @@protoc_insertion_point(class_scope:mangaplus_api.HomeViewV4.WeeklySection.MVBanner)
      })
    ,

    'TitleGroup' : _reflection.GeneratedProtocolMessageType('TitleGroup', (_message.Message,), {
      'DESCRIPTOR' : _HOMEVIEWV4_WEEKLYSECTION_TITLEGROUP,
      '__module__' : 'mangaplus_api_pb2'
      # @@protoc_insertion_point(class_scope:mangaplus_api.HomeViewV4.WeeklySection.TitleGroup)
      })
    ,

    'CarouselBanner' : _reflection.GeneratedProtocolMessageType('CarouselBanner', (_message.Message,), {
      'DESCRIPTOR' : _HOMEVIEWV4_WEEKLYSECTION_CAROUSELBANNER,
      '__module__' : 'mangaplus_api_pb2'
      # @@protoc_insertion_point(class_scope:mangaplus_api.HomeViewV4.WeeklySection.CarouselBanner)
      })
    ,

    'MinorLanguageBanner' : _reflection.GeneratedProtocolMessageType('MinorLanguageBanner', (_message.Message,), {
      'DESCRIPTOR' : _HOMEVIEWV4_WEEKLYSECTION_MINORLANGUAGEBANNER,
      '__module__' : 'mangaplus_api_pb2'
      # @@protoc_insertion_point(class_scope:mangaplus_api.HomeViewV4.WeeklySection.MinorLanguageBanner)
      })
    ,
    'DESCRIPTOR' : _HOMEVIEWV4_WEEKLYSECTION,
    '__module__' : 'mangaplus_api_pb2'
    # @@protoc_insertion_point(class_scope:mangaplus_api.HomeViewV4.WeeklySection)
    })
  ,

  'RankingSection' : _reflection.GeneratedProtocolMessageType('RankingSection', (_message.Message,), {

    'RankingTab' : _reflection.GeneratedProtocolMessageType('RankingTab', (_message.Message,), {
      'DESCRIPTOR' : _HOMEVIEWV4_RANKINGSECTION_RANKINGTAB,
      '__module__' : 'mangaplus_api_pb2'
      # @@protoc_insertion_point(class_scope:mangaplus_api.HomeViewV4.RankingSection.RankingTab)
      })
    ,
    'DESCRIPTOR' : _HOMEVIEWV4_RANKINGSECTION,
    '__module__' : 'mangaplus_api_pb2'
    # @@protoc_insertion_point(class_scope:mangaplus_api.HomeViewV4.RankingSection)
    })
  ,

  'PreviewSection' : _reflection.GeneratedProtocolMessageType('PreviewSection', (_message.Message,), {

    'PreviewTab' : _reflection.GeneratedProtocolMessageType('PreviewTab', (_message.Message,), {
      'DESCRIPTOR' : _HOMEVIEWV4_PREVIEWSECTION_PREVIEWTAB,
      '__module__' : 'mangaplus_api_pb2'
      # @@protoc_insertion_point(class_scope:mangaplus_api.HomeViewV4.PreviewSection.PreviewTab)
      })
    ,
    'DESCRIPTOR' : _HOMEVIEWV4_PREVIEWSECTION,
    '__module__' : 'mangaplus_api_pb2'
    # @@protoc_insertion_point(class_scope:mangaplus_api.HomeViewV4.PreviewSection)
    })
  ,

  'TitleListSection' : _reflection.GeneratedProtocolMessageType('TitleListSection', (_message.Message,), {
    'DESCRIPTOR' : _HOMEVIEWV4_TITLELISTSECTION,
    '__module__' : 'mangaplus_api_pb2'
    # @@protoc_insertion_point(class_scope:mangaplus_api.HomeViewV4.TitleListSection)
    })
  ,

  'BannerSection' : _reflection.GeneratedProtocolMessageType('BannerSection', (_message.Message,), {
    'DESCRIPTOR' : _HOMEVIEWV4_BANNERSECTION,
    '__module__' : 'mangaplus_api_pb2'
    # @@protoc_insertion_point(class_scope:mangaplus_api.HomeViewV4.BannerSection)
    })
  ,
  'DESCRIPTOR' : _HOMEVIEWV4,
  '__module__' : 'mangaplus_api_pb2'
  # @@protoc_insertion_point(class_scope:mangaplus_api.HomeViewV4)
  })
_sym_db.RegisterMessage(HomeViewV4)
_sym_db.RegisterMessage(HomeViewV4.Sections)
_sym_db.RegisterMessage(HomeViewV4.WeeklySection)
_sym_db.RegisterMessage(HomeViewV4.WeeklySection.WeeklyContent)
_sym_db.RegisterMessage(HomeViewV4.WeeklySection.ContentItem)
_sym_db.RegisterMessage(HomeViewV4.WeeklySection.MVBanner)
_sym_db.RegisterMessage(HomeViewV4.WeeklySection.TitleGroup)
_sym_db.RegisterMessage(HomeViewV4.WeeklySection.CarouselBanner)
_sym_db.RegisterMessage(HomeViewV4.WeeklySection.MinorLanguageBanner)
_sym_db.RegisterMessage(HomeViewV4.RankingSection)
_sym_db.RegisterMessage(HomeViewV4.RankingSection.RankingTab)
_sym_db.RegisterMessage(HomeViewV4.PreviewSection)
_sym_db.RegisterMessage(HomeViewV4.PreviewSection.PreviewTab)
_sym_db.RegisterMessage(HomeViewV4.TitleListSection)
_sym_db.RegisterMessage(HomeViewV4.BannerSection)

InitialViewV2 = _reflection.GeneratedProtocolMessageType('InitialViewV2', (_message.Message,), {
  'DESCRIPTOR' : _INITIALVIEWV2,
  '__module__' : 'mangaplus_api_pb2'
  # @@protoc_insertion_point(class_scope:mangaplus_api.InitialViewV2)
  })
_sym_db.RegisterMessage(InitialViewV2)

IntroduceSubscription = _reflection.GeneratedProtocolMessageType('IntroduceSubscription', (_message.Message,), {
  'DESCRIPTOR' : _INTRODUCESUBSCRIPTION,
  '__module__' : 'mangaplus_api_pb2'
  # @@protoc_insertion_point(class_scope:mangaplus_api.IntroduceSubscription)
  })
_sym_db.RegisterMessage(IntroduceSubscription)

LabeledView = _reflection.GeneratedProtocolMessageType('LabeledView', (_message.Message,), {
  'DESCRIPTOR' : _LABELEDVIEW,
  '__module__' : 'mangaplus_api_pb2'
  # @@protoc_insertion_point(class_scope:mangaplus_api.LabeledView)
  })
_sym_db.RegisterMessage(LabeledView)

Label = _reflection.GeneratedProtocolMessageType('Label', (_message.Message,), {
  'DESCRIPTOR' : _LABEL,
  '__module__' : 'mangaplus_api_pb2'
  # @@protoc_insertion_point(class_scope:mangaplus_api.Label)
  })
_sym_db.RegisterMessage(Label)

Languages = _reflection.GeneratedProtocolMessageType('Languages', (_message.Message,), {
  'DESCRIPTOR' : _LANGUAGES,
  '__module__' : 'mangaplus_api_pb2'
  # @@protoc_insertion_point(class_scope:mangaplus_api.Languages)
  })
_sym_db.RegisterMessage(Languages)

AvailableLanguages = _reflection.GeneratedProtocolMessageType('AvailableLanguages', (_message.Message,), {
  'DESCRIPTOR' : _AVAILABLELANGUAGES,
  '__module__' : 'mangaplus_api_pb2'
  # @@protoc_insertion_point(class_scope:mangaplus_api.AvailableLanguages)
  })
_sym_db.RegisterMessage(AvailableLanguages)

MangaViewer = _reflection.GeneratedProtocolMessageType('MangaViewer', (_message.Message,), {

  'TitleAvailableLanguages' : _reflection.GeneratedProtocolMessageType('TitleAvailableLanguages', (_message.Message,), {
    'DESCRIPTOR' : _MANGAVIEWER_TITLEAVAILABLELANGUAGES,
    '__module__' : 'mangaplus_api_pb2'
    # @@protoc_insertion_point(class_scope:mangaplus_api.MangaViewer.TitleAvailableLanguages)
    })
  ,
  'DESCRIPTOR' : _MANGAVIEWER,
  '__module__' : 'mangaplus_api_pb2'
  # @@protoc_insertion_point(class_scope:mangaplus_api.MangaViewer)
  })
_sym_db.RegisterMessage(MangaViewer)
_sym_db.RegisterMessage(MangaViewer.TitleAvailableLanguages)

MetaInfo = _reflection.GeneratedProtocolMessageType('MetaInfo', (_message.Message,), {
  'DESCRIPTOR' : _METAINFO,
  '__module__' : 'mangaplus_api_pb2'
  # @@protoc_insertion_point(class_scope:mangaplus_api.MetaInfo)
  })
_sym_db.RegisterMessage(MetaInfo)

MpcStatusView = _reflection.GeneratedProtocolMessageType('MpcStatusView', (_message.Message,), {
  'DESCRIPTOR' : _MPCSTATUSVIEW,
  '__module__' : 'mangaplus_api_pb2'
  # @@protoc_insertion_point(class_scope:mangaplus_api.MpcStatusView)
  })
_sym_db.RegisterMessage(MpcStatusView)

Page = _reflection.GeneratedProtocolMessageType('Page', (_message.Message,), {

  'MangaPage' : _reflection.GeneratedProtocolMessageType('MangaPage', (_message.Message,), {
    'DESCRIPTOR' : _PAGE_MANGAPAGE,
    '__module__' : 'mangaplus_api_pb2'
    # @@protoc_insertion_point(class_scope:mangaplus_api.Page.MangaPage)
    })
  ,

  'LastPage' : _reflection.GeneratedProtocolMessageType('LastPage', (_message.Message,), {
    'DESCRIPTOR' : _PAGE_LASTPAGE,
    '__module__' : 'mangaplus_api_pb2'
    # @@protoc_insertion_point(class_scope:mangaplus_api.Page.LastPage)
    })
  ,

  'BannerList' : _reflection.GeneratedProtocolMessageType('BannerList', (_message.Message,), {
    'DESCRIPTOR' : _PAGE_BANNERLIST,
    '__module__' : 'mangaplus_api_pb2'
    # @@protoc_insertion_point(class_scope:mangaplus_api.Page.BannerList)
    })
  ,
  'DESCRIPTOR' : _PAGE,
  '__module__' : 'mangaplus_api_pb2'
  # @@protoc_insertion_point(class_scope:mangaplus_api.Page)
  })
_sym_db.RegisterMessage(Page)
_sym_db.RegisterMessage(Page.MangaPage)
_sym_db.RegisterMessage(Page.LastPage)
_sym_db.RegisterMessage(Page.BannerList)

Popup = _reflection.GeneratedProtocolMessageType('Popup', (_message.Message,), {

  'OSDefault' : _reflection.GeneratedProtocolMessageType('OSDefault', (_message.Message,), {
    'DESCRIPTOR' : _POPUP_OSDEFAULT,
    '__module__' : 'mangaplus_api_pb2'
    # @@protoc_insertion_point(class_scope:mangaplus_api.Popup.OSDefault)
    })
  ,

  'AppDefault' : _reflection.GeneratedProtocolMessageType('AppDefault', (_message.Message,), {
    'DESCRIPTOR' : _POPUP_APPDEFAULT,
    '__module__' : 'mangaplus_api_pb2'
    # @@protoc_insertion_point(class_scope:mangaplus_api.Popup.AppDefault)
    })
  ,

  'OneImage' : _reflection.GeneratedProtocolMessageType('OneImage', (_message.Message,), {
    'DESCRIPTOR' : _POPUP_ONEIMAGE,
    '__module__' : 'mangaplus_api_pb2'
    # @@protoc_insertion_point(class_scope:mangaplus_api.Popup.OneImage)
    })
  ,

  'Button' : _reflection.GeneratedProtocolMessageType('Button', (_message.Message,), {
    'DESCRIPTOR' : _POPUP_BUTTON,
    '__module__' : 'mangaplus_api_pb2'
    # @@protoc_insertion_point(class_scope:mangaplus_api.Popup.Button)
    })
  ,
  'DESCRIPTOR' : _POPUP,
  '__module__' : 'mangaplus_api_pb2'
  # @@protoc_insertion_point(class_scope:mangaplus_api.Popup)
  })
_sym_db.RegisterMessage(Popup)
_sym_db.RegisterMessage(Popup.OSDefault)
_sym_db.RegisterMessage(Popup.AppDefault)
_sym_db.RegisterMessage(Popup.OneImage)
_sym_db.RegisterMessage(Popup.Button)

MovieReward = _reflection.GeneratedProtocolMessageType('MovieReward', (_message.Message,), {
  'DESCRIPTOR' : _MOVIEREWARD,
  '__module__' : 'mangaplus_api_pb2'
  # @@protoc_insertion_point(class_scope:mangaplus_api.MovieReward)
  })
_sym_db.RegisterMessage(MovieReward)

ProfileSettingsView = _reflection.GeneratedProtocolMessageType('ProfileSettingsView', (_message.Message,), {
  'DESCRIPTOR' : _PROFILESETTINGSVIEW,
  '__module__' : 'mangaplus_api_pb2'
  # @@protoc_insertion_point(class_scope:mangaplus_api.ProfileSettingsView)
  })
_sym_db.RegisterMessage(ProfileSettingsView)

PublisherNewsListView = _reflection.GeneratedProtocolMessageType('PublisherNewsListView', (_message.Message,), {
  'DESCRIPTOR' : _PUBLISHERNEWSLISTVIEW,
  '__module__' : 'mangaplus_api_pb2'
  # @@protoc_insertion_point(class_scope:mangaplus_api.PublisherNewsListView)
  })
_sym_db.RegisterMessage(PublisherNewsListView)

PublisherNews = _reflection.GeneratedProtocolMessageType('PublisherNews', (_message.Message,), {
  'DESCRIPTOR' : _PUBLISHERNEWS,
  '__module__' : 'mangaplus_api_pb2'
  # @@protoc_insertion_point(class_scope:mangaplus_api.PublisherNews)
  })
_sym_db.RegisterMessage(PublisherNews)

PushTokenView = _reflection.GeneratedProtocolMessageType('PushTokenView', (_message.Message,), {
  'DESCRIPTOR' : _PUSHTOKENVIEW,
  '__module__' : 'mangaplus_api_pb2'
  # @@protoc_insertion_point(class_scope:mangaplus_api.PushTokenView)
  })
_sym_db.RegisterMessage(PushTokenView)

Questionnaire = _reflection.GeneratedProtocolMessageType('Questionnaire', (_message.Message,), {
  'DESCRIPTOR' : _QUESTIONNAIRE,
  '__module__' : 'mangaplus_api_pb2'
  # @@protoc_insertion_point(class_scope:mangaplus_api.Questionnaire)
  })
_sym_db.RegisterMessage(Questionnaire)

QuestionnaireView = _reflection.GeneratedProtocolMessageType('QuestionnaireView', (_message.Message,), {
  'DESCRIPTOR' : _QUESTIONNAIREVIEW,
  '__module__' : 'mangaplus_api_pb2'
  # @@protoc_insertion_point(class_scope:mangaplus_api.QuestionnaireView)
  })
_sym_db.RegisterMessage(QuestionnaireView)

RegistrationData = _reflection.GeneratedProtocolMessageType('RegistrationData', (_message.Message,), {
  'DESCRIPTOR' : _REGISTRATIONDATA,
  '__module__' : 'mangaplus_api_pb2'
  # @@protoc_insertion_point(class_scope:mangaplus_api.RegistrationData)
  })
_sym_db.RegisterMessage(RegistrationData)

Response = _reflection.GeneratedProtocolMessageType('Response', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSE,
  '__module__' : 'mangaplus_api_pb2'
  # @@protoc_insertion_point(class_scope:mangaplus_api.Response)
  })
_sym_db.RegisterMessage(Response)

SearchView = _reflection.GeneratedProtocolMessageType('SearchView', (_message.Message,), {

  'Contents' : _reflection.GeneratedProtocolMessageType('Contents', (_message.Message,), {
    'DESCRIPTOR' : _SEARCHVIEW_CONTENTS,
    '__module__' : 'mangaplus_api_pb2'
    # @@protoc_insertion_point(class_scope:mangaplus_api.SearchView.Contents)
    })
  ,
  'DESCRIPTOR' : _SEARCHVIEW,
  '__module__' : 'mangaplus_api_pb2'
  # @@protoc_insertion_point(class_scope:mangaplus_api.SearchView)
  })
_sym_db.RegisterMessage(SearchView)
_sym_db.RegisterMessage(SearchView.Contents)

ServiceAnnouncement = _reflection.GeneratedProtocolMessageType('ServiceAnnouncement', (_message.Message,), {
  'DESCRIPTOR' : _SERVICEANNOUNCEMENT,
  '__module__' : 'mangaplus_api_pb2'
  # @@protoc_insertion_point(class_scope:mangaplus_api.ServiceAnnouncement)
  })
_sym_db.RegisterMessage(ServiceAnnouncement)

ServiceAnnouncementsView = _reflection.GeneratedProtocolMessageType('ServiceAnnouncementsView', (_message.Message,), {
  'DESCRIPTOR' : _SERVICEANNOUNCEMENTSVIEW,
  '__module__' : 'mangaplus_api_pb2'
  # @@protoc_insertion_point(class_scope:mangaplus_api.ServiceAnnouncementsView)
  })
_sym_db.RegisterMessage(ServiceAnnouncementsView)

SettingsView = _reflection.GeneratedProtocolMessageType('SettingsView', (_message.Message,), {
  'DESCRIPTOR' : _SETTINGSVIEW,
  '__module__' : 'mangaplus_api_pb2'
  # @@protoc_insertion_point(class_scope:mangaplus_api.SettingsView)
  })
_sym_db.RegisterMessage(SettingsView)

SettingsViewV2 = _reflection.GeneratedProtocolMessageType('SettingsViewV2', (_message.Message,), {
  'DESCRIPTOR' : _SETTINGSVIEWV2,
  '__module__' : 'mangaplus_api_pb2'
  # @@protoc_insertion_point(class_scope:mangaplus_api.SettingsViewV2)
  })
_sym_db.RegisterMessage(SettingsViewV2)

CustomCodeDialogue = _reflection.GeneratedProtocolMessageType('CustomCodeDialogue', (_message.Message,), {
  'DESCRIPTOR' : _CUSTOMCODEDIALOGUE,
  '__module__' : 'mangaplus_api_pb2'
  # @@protoc_insertion_point(class_scope:mangaplus_api.CustomCodeDialogue)
  })
_sym_db.RegisterMessage(CustomCodeDialogue)

Sns = _reflection.GeneratedProtocolMessageType('Sns', (_message.Message,), {
  'DESCRIPTOR' : _SNS,
  '__module__' : 'mangaplus_api_pb2'
  # @@protoc_insertion_point(class_scope:mangaplus_api.Sns)
  })
_sym_db.RegisterMessage(Sns)

SubscribedTitlesView = _reflection.GeneratedProtocolMessageType('SubscribedTitlesView', (_message.Message,), {
  'DESCRIPTOR' : _SUBSCRIBEDTITLESVIEW,
  '__module__' : 'mangaplus_api_pb2'
  # @@protoc_insertion_point(class_scope:mangaplus_api.SubscribedTitlesView)
  })
_sym_db.RegisterMessage(SubscribedTitlesView)

IosSubscriptionOffer = _reflection.GeneratedProtocolMessageType('IosSubscriptionOffer', (_message.Message,), {
  'DESCRIPTOR' : _IOSSUBSCRIPTIONOFFER,
  '__module__' : 'mangaplus_api_pb2'
  # @@protoc_insertion_point(class_scope:mangaplus_api.IosSubscriptionOffer)
  })
_sym_db.RegisterMessage(IosSubscriptionOffer)

AndroidSubscriptionOfferTags = _reflection.GeneratedProtocolMessageType('AndroidSubscriptionOfferTags', (_message.Message,), {
  'DESCRIPTOR' : _ANDROIDSUBSCRIPTIONOFFERTAGS,
  '__module__' : 'mangaplus_api_pb2'
  # @@protoc_insertion_point(class_scope:mangaplus_api.AndroidSubscriptionOfferTags)
  })
_sym_db.RegisterMessage(AndroidSubscriptionOfferTags)

Subscription = _reflection.GeneratedProtocolMessageType('Subscription', (_message.Message,), {
  'DESCRIPTOR' : _SUBSCRIPTION,
  '__module__' : 'mangaplus_api_pb2'
  # @@protoc_insertion_point(class_scope:mangaplus_api.Subscription)
  })
_sym_db.RegisterMessage(Subscription)

PlanType = _reflection.GeneratedProtocolMessageType('PlanType', (_message.Message,), {
  'DESCRIPTOR' : _PLANTYPE,
  '__module__' : 'mangaplus_api_pb2'
  # @@protoc_insertion_point(class_scope:mangaplus_api.PlanType)
  })
_sym_db.RegisterMessage(PlanType)

SubscriptionView = _reflection.GeneratedProtocolMessageType('SubscriptionView', (_message.Message,), {
  'DESCRIPTOR' : _SUBSCRIPTIONVIEW,
  '__module__' : 'mangaplus_api_pb2'
  # @@protoc_insertion_point(class_scope:mangaplus_api.SubscriptionView)
  })
_sym_db.RegisterMessage(SubscriptionView)

SubscriptionPlanBoxDescription = _reflection.GeneratedProtocolMessageType('SubscriptionPlanBoxDescription', (_message.Message,), {
  'DESCRIPTOR' : _SUBSCRIPTIONPLANBOXDESCRIPTION,
  '__module__' : 'mangaplus_api_pb2'
  # @@protoc_insertion_point(class_scope:mangaplus_api.SubscriptionPlanBoxDescription)
  })
_sym_db.RegisterMessage(SubscriptionPlanBoxDescription)

SubscriptionNote = _reflection.GeneratedProtocolMessageType('SubscriptionNote', (_message.Message,), {
  'DESCRIPTOR' : _SUBSCRIPTIONNOTE,
  '__module__' : 'mangaplus_api_pb2'
  # @@protoc_insertion_point(class_scope:mangaplus_api.SubscriptionNote)
  })
_sym_db.RegisterMessage(SubscriptionNote)

SuccessResult = _reflection.GeneratedProtocolMessageType('SuccessResult', (_message.Message,), {
  'DESCRIPTOR' : _SUCCESSRESULT,
  '__module__' : 'mangaplus_api_pb2'
  # @@protoc_insertion_point(class_scope:mangaplus_api.SuccessResult)
  })
_sym_db.RegisterMessage(SuccessResult)

Tag = _reflection.GeneratedProtocolMessageType('Tag', (_message.Message,), {
  'DESCRIPTOR' : _TAG,
  '__module__' : 'mangaplus_api_pb2'
  # @@protoc_insertion_point(class_scope:mangaplus_api.Tag)
  })
_sym_db.RegisterMessage(Tag)

TitleDetailView = _reflection.GeneratedProtocolMessageType('TitleDetailView', (_message.Message,), {

  'TitleLabels' : _reflection.GeneratedProtocolMessageType('TitleLabels', (_message.Message,), {
    'DESCRIPTOR' : _TITLEDETAILVIEW_TITLELABELS,
    '__module__' : 'mangaplus_api_pb2'
    # @@protoc_insertion_point(class_scope:mangaplus_api.TitleDetailView.TitleLabels)
    })
  ,

  'PublisherItem' : _reflection.GeneratedProtocolMessageType('PublisherItem', (_message.Message,), {
    'DESCRIPTOR' : _TITLEDETAILVIEW_PUBLISHERITEM,
    '__module__' : 'mangaplus_api_pb2'
    # @@protoc_insertion_point(class_scope:mangaplus_api.TitleDetailView.PublisherItem)
    })
  ,

  'TitleLanguages' : _reflection.GeneratedProtocolMessageType('TitleLanguages', (_message.Message,), {
    'DESCRIPTOR' : _TITLEDETAILVIEW_TITLELANGUAGES,
    '__module__' : 'mangaplus_api_pb2'
    # @@protoc_insertion_point(class_scope:mangaplus_api.TitleDetailView.TitleLanguages)
    })
  ,

  'ChapterGroup' : _reflection.GeneratedProtocolMessageType('ChapterGroup', (_message.Message,), {
    'DESCRIPTOR' : _TITLEDETAILVIEW_CHAPTERGROUP,
    '__module__' : 'mangaplus_api_pb2'
    # @@protoc_insertion_point(class_scope:mangaplus_api.TitleDetailView.ChapterGroup)
    })
  ,
  'DESCRIPTOR' : _TITLEDETAILVIEW,
  '__module__' : 'mangaplus_api_pb2'
  # @@protoc_insertion_point(class_scope:mangaplus_api.TitleDetailView)
  })
_sym_db.RegisterMessage(TitleDetailView)
_sym_db.RegisterMessage(TitleDetailView.TitleLabels)
_sym_db.RegisterMessage(TitleDetailView.PublisherItem)
_sym_db.RegisterMessage(TitleDetailView.TitleLanguages)
_sym_db.RegisterMessage(TitleDetailView.ChapterGroup)

AllTitlesGroup = _reflection.GeneratedProtocolMessageType('AllTitlesGroup', (_message.Message,), {
  'DESCRIPTOR' : _ALLTITLESGROUP,
  '__module__' : 'mangaplus_api_pb2'
  # @@protoc_insertion_point(class_scope:mangaplus_api.AllTitlesGroup)
  })
_sym_db.RegisterMessage(AllTitlesGroup)

TitleRankingGroup = _reflection.GeneratedProtocolMessageType('TitleRankingGroup', (_message.Message,), {
  'DESCRIPTOR' : _TITLERANKINGGROUP,
  '__module__' : 'mangaplus_api_pb2'
  # @@protoc_insertion_point(class_scope:mangaplus_api.TitleRankingGroup)
  })
_sym_db.RegisterMessage(TitleRankingGroup)

TitleUpdatedGroup = _reflection.GeneratedProtocolMessageType('TitleUpdatedGroup', (_message.Message,), {
  'DESCRIPTOR' : _TITLEUPDATEDGROUP,
  '__module__' : 'mangaplus_api_pb2'
  # @@protoc_insertion_point(class_scope:mangaplus_api.TitleUpdatedGroup)
  })
_sym_db.RegisterMessage(TitleUpdatedGroup)

LabeledTitlesGroup = _reflection.GeneratedProtocolMessageType('LabeledTitlesGroup', (_message.Message,), {
  'DESCRIPTOR' : _LABELEDTITLESGROUP,
  '__module__' : 'mangaplus_api_pb2'
  # @@protoc_insertion_point(class_scope:mangaplus_api.LabeledTitlesGroup)
  })
_sym_db.RegisterMessage(LabeledTitlesGroup)

TitleSubscriptionGroup = _reflection.GeneratedProtocolMessageType('TitleSubscriptionGroup', (_message.Message,), {
  'DESCRIPTOR' : _TITLESUBSCRIPTIONGROUP,
  '__module__' : 'mangaplus_api_pb2'
  # @@protoc_insertion_point(class_scope:mangaplus_api.TitleSubscriptionGroup)
  })
_sym_db.RegisterMessage(TitleSubscriptionGroup)

TitleList = _reflection.GeneratedProtocolMessageType('TitleList', (_message.Message,), {
  'DESCRIPTOR' : _TITLELIST,
  '__module__' : 'mangaplus_api_pb2'
  # @@protoc_insertion_point(class_scope:mangaplus_api.TitleList)
  })
_sym_db.RegisterMessage(TitleList)

ChapterPageList = _reflection.GeneratedProtocolMessageType('ChapterPageList', (_message.Message,), {
  'DESCRIPTOR' : _CHAPTERPAGELIST,
  '__module__' : 'mangaplus_api_pb2'
  # @@protoc_insertion_point(class_scope:mangaplus_api.ChapterPageList)
  })
_sym_db.RegisterMessage(ChapterPageList)

ChapterPages = _reflection.GeneratedProtocolMessageType('ChapterPages', (_message.Message,), {
  'DESCRIPTOR' : _CHAPTERPAGES,
  '__module__' : 'mangaplus_api_pb2'
  # @@protoc_insertion_point(class_scope:mangaplus_api.ChapterPages)
  })
_sym_db.RegisterMessage(ChapterPages)

Title = _reflection.GeneratedProtocolMessageType('Title', (_message.Message,), {
  'DESCRIPTOR' : _TITLE,
  '__module__' : 'mangaplus_api_pb2'
  # @@protoc_insertion_point(class_scope:mangaplus_api.Title)
  })
_sym_db.RegisterMessage(Title)

UpdatedTitle = _reflection.GeneratedProtocolMessageType('UpdatedTitle', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDTITLE,
  '__module__' : 'mangaplus_api_pb2'
  # @@protoc_insertion_point(class_scope:mangaplus_api.UpdatedTitle)
  })
_sym_db.RegisterMessage(UpdatedTitle)

TitleUpdated = _reflection.GeneratedProtocolMessageType('TitleUpdated', (_message.Message,), {
  'DESCRIPTOR' : _TITLEUPDATED,
  '__module__' : 'mangaplus_api_pb2'
  # @@protoc_insertion_point(class_scope:mangaplus_api.TitleUpdated)
  })
_sym_db.RegisterMessage(TitleUpdated)

FreeTitle = _reflection.GeneratedProtocolMessageType('FreeTitle', (_message.Message,), {
  'DESCRIPTOR' : _FREETITLE,
  '__module__' : 'mangaplus_api_pb2'
  # @@protoc_insertion_point(class_scope:mangaplus_api.FreeTitle)
  })
_sym_db.RegisterMessage(FreeTitle)

TicketTitles = _reflection.GeneratedProtocolMessageType('TicketTitles', (_message.Message,), {
  'DESCRIPTOR' : _TICKETTITLES,
  '__module__' : 'mangaplus_api_pb2'
  # @@protoc_insertion_point(class_scope:mangaplus_api.TicketTitles)
  })
_sym_db.RegisterMessage(TicketTitles)

SubscribableTitle = _reflection.GeneratedProtocolMessageType('SubscribableTitle', (_message.Message,), {
  'DESCRIPTOR' : _SUBSCRIBABLETITLE,
  '__module__' : 'mangaplus_api_pb2'
  # @@protoc_insertion_point(class_scope:mangaplus_api.SubscribableTitle)
  })
_sym_db.RegisterMessage(SubscribableTitle)

ComingSoonTitle = _reflection.GeneratedProtocolMessageType('ComingSoonTitle', (_message.Message,), {
  'DESCRIPTOR' : _COMINGSOONTITLE,
  '__module__' : 'mangaplus_api_pb2'
  # @@protoc_insertion_point(class_scope:mangaplus_api.ComingSoonTitle)
  })
_sym_db.RegisterMessage(ComingSoonTitle)

TitleHighlight = _reflection.GeneratedProtocolMessageType('TitleHighlight', (_message.Message,), {
  'DESCRIPTOR' : _TITLEHIGHLIGHT,
  '__module__' : 'mangaplus_api_pb2'
  # @@protoc_insertion_point(class_scope:mangaplus_api.TitleHighlight)
  })
_sym_db.RegisterMessage(TitleHighlight)

TitleRankingView = _reflection.GeneratedProtocolMessageType('TitleRankingView', (_message.Message,), {
  'DESCRIPTOR' : _TITLERANKINGVIEW,
  '__module__' : 'mangaplus_api_pb2'
  # @@protoc_insertion_point(class_scope:mangaplus_api.TitleRankingView)
  })
_sym_db.RegisterMessage(TitleRankingView)

TitleRankingViewV2 = _reflection.GeneratedProtocolMessageType('TitleRankingViewV2', (_message.Message,), {
  'DESCRIPTOR' : _TITLERANKINGVIEWV2,
  '__module__' : 'mangaplus_api_pb2'
  # @@protoc_insertion_point(class_scope:mangaplus_api.TitleRankingViewV2)
  })
_sym_db.RegisterMessage(TitleRankingViewV2)

TitleUpdatedView = _reflection.GeneratedProtocolMessageType('TitleUpdatedView', (_message.Message,), {
  'DESCRIPTOR' : _TITLEUPDATEDVIEW,
  '__module__' : 'mangaplus_api_pb2'
  # @@protoc_insertion_point(class_scope:mangaplus_api.TitleUpdatedView)
  })
_sym_db.RegisterMessage(TitleUpdatedView)

TitleUpdatedViewV2 = _reflection.GeneratedProtocolMessageType('TitleUpdatedViewV2', (_message.Message,), {
  'DESCRIPTOR' : _TITLEUPDATEDVIEWV2,
  '__module__' : 'mangaplus_api_pb2'
  # @@protoc_insertion_point(class_scope:mangaplus_api.TitleUpdatedViewV2)
  })
_sym_db.RegisterMessage(TitleUpdatedViewV2)

TransitionAction = _reflection.GeneratedProtocolMessageType('TransitionAction', (_message.Message,), {
  'DESCRIPTOR' : _TRANSITIONACTION,
  '__module__' : 'mangaplus_api_pb2'
  # @@protoc_insertion_point(class_scope:mangaplus_api.TransitionAction)
  })
_sym_db.RegisterMessage(TransitionAction)

UpdatedTitleGroup = _reflection.GeneratedProtocolMessageType('UpdatedTitleGroup', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDTITLEGROUP,
  '__module__' : 'mangaplus_api_pb2'
  # @@protoc_insertion_point(class_scope:mangaplus_api.UpdatedTitleGroup)
  })
_sym_db.RegisterMessage(UpdatedTitleGroup)

UpdatedTitleV2Group = _reflection.GeneratedProtocolMessageType('UpdatedTitleV2Group', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDTITLEV2GROUP,
  '__module__' : 'mangaplus_api_pb2'
  # @@protoc_insertion_point(class_scope:mangaplus_api.UpdatedTitleV2Group)
  })
_sym_db.RegisterMessage(UpdatedTitleV2Group)

OriginalTitleGroup = _reflection.GeneratedProtocolMessageType('OriginalTitleGroup', (_message.Message,), {
  'DESCRIPTOR' : _ORIGINALTITLEGROUP,
  '__module__' : 'mangaplus_api_pb2'
  # @@protoc_insertion_point(class_scope:mangaplus_api.OriginalTitleGroup)
  })
_sym_db.RegisterMessage(OriginalTitleGroup)

UpdatedTitleListView = _reflection.GeneratedProtocolMessageType('UpdatedTitleListView', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDTITLELISTVIEW,
  '__module__' : 'mangaplus_api_pb2'
  # @@protoc_insertion_point(class_scope:mangaplus_api.UpdatedTitleListView)
  })
_sym_db.RegisterMessage(UpdatedTitleListView)

UpdateProfileResultView = _reflection.GeneratedProtocolMessageType('UpdateProfileResultView', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEPROFILERESULTVIEW,
  '__module__' : 'mangaplus_api_pb2'
  # @@protoc_insertion_point(class_scope:mangaplus_api.UpdateProfileResultView)
  })
_sym_db.RegisterMessage(UpdateProfileResultView)

UserTickets = _reflection.GeneratedProtocolMessageType('UserTickets', (_message.Message,), {
  'DESCRIPTOR' : _USERTICKETS,
  '__module__' : 'mangaplus_api_pb2'
  # @@protoc_insertion_point(class_scope:mangaplus_api.UserTickets)
  })
_sym_db.RegisterMessage(UserTickets)

WebHomeViewV4 = _reflection.GeneratedProtocolMessageType('WebHomeViewV4', (_message.Message,), {
  'DESCRIPTOR' : _WEBHOMEVIEWV4,
  '__module__' : 'mangaplus_api_pb2'
  # @@protoc_insertion_point(class_scope:mangaplus_api.WebHomeViewV4)
  })
_sym_db.RegisterMessage(WebHomeViewV4)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026jp.co.comic.jump.proto'
  _FIRSTTIMEFREEPLATFORM._serialized_start=23511
  _FIRSTTIMEFREEPLATFORM._serialized_end=23566
  _LABELCODES._serialized_start=23569
  _LABELCODES._serialized_end=23717
  _LANGUAGE._serialized_start=23720
  _LANGUAGE._serialized_end=23867
  _RANKINGTABTYPE._serialized_start=23869
  _RANKINGTABTYPE._serialized_end=23927
  _TITLEUPDATESTATUS._serialized_start=23929
  _TITLEUPDATESTATUS._serialized_end=24026
  _ADNETWORKLIST._serialized_start=38
  _ADNETWORKLIST._serialized_end=99
  _ADREWARDNETWORKLIST._serialized_start=101
  _ADREWARDNETWORKLIST._serialized_end=208
  _ADNETWORK._serialized_start=211
  _ADNETWORK._serialized_end=992
  _ADNETWORK_FACEBOOK._serialized_start=534
  _ADNETWORK_FACEBOOK._serialized_end=565
  _ADNETWORK_ADMOB._serialized_start=567
  _ADNETWORK_ADMOB._serialized_end=590
  _ADNETWORK_ADSENSE._serialized_start=592
  _ADNETWORK_ADSENSE._serialized_end=635
  _ADNETWORK_APPLOVIN._serialized_start=637
  _ADNETWORK_APPLOVIN._serialized_end=663
  _ADNETWORK_MOPUB._serialized_start=665
  _ADNETWORK_MOPUB._serialized_end=688
  _ADNETWORK_APPLOVINMAX._serialized_start=690
  _ADNETWORK_APPLOVINMAX._serialized_end=778
  _ADNETWORK_ADTYPE._serialized_start=780
  _ADNETWORK_ADTYPE._serialized_end=876
  _ADNETWORK_NETWORKCASE._serialized_start=878
  _ADNETWORK_NETWORKCASE._serialized_end=992
  _ALLFREETITLESVIEW._serialized_start=994
  _ALLFREETITLESVIEW._serialized_end=1059
  _ALLTICKETTITLESVIEW._serialized_start=1061
  _ALLTICKETTITLESVIEW._serialized_end=1132
  _ALLTITLESVIEW._serialized_start=1134
  _ALLTITLESVIEW._serialized_end=1187
  _ALLTITLESVIEWV2._serialized_start=1189
  _ALLTITLESVIEWV2._serialized_end=1261
  _BANNER._serialized_start=1264
  _BANNER._serialized_end=1396
  _CHAPTER._serialized_start=1399
  _CHAPTER._serialized_end=1711
  _COMMENTICON._serialized_start=1713
  _COMMENTICON._serialized_end=1756
  _COMMENTLISTVIEW._serialized_start=1759
  _COMMENTLISTVIEW._serialized_end=2015
  _COMMENTLISTVIEW_TITLEDETAILCOMMENT._serialized_start=1922
  _COMMENTLISTVIEW_TITLEDETAILCOMMENT._serialized_end=2015
  _COMMENT._serialized_start=2018
  _COMMENT._serialized_end=2186
  _FREEVIEWDIALOGUE._serialized_start=2189
  _FREEVIEWDIALOGUE._serialized_end=2332
  _DOWNLOADABLEIMAGESVIEW._serialized_start=2334
  _DOWNLOADABLEIMAGESVIEW._serialized_end=2425
  _DOWNLOADABLEIMAGEGROUP._serialized_start=2427
  _DOWNLOADABLEIMAGEGROUP._serialized_end=2546
  _ERRORRESULT._serialized_start=2549
  _ERRORRESULT._serialized_end=2866
  _ERRORRESULT_ACTION._serialized_start=2790
  _ERRORRESULT_ACTION._serialized_end=2866
  _FAVORITETITLESVIEW._serialized_start=2869
  _FAVORITETITLESVIEW._serialized_end=3011
  _FAVORITETITLEGROUP._serialized_start=3013
  _FAVORITETITLEGROUP._serialized_end=3114
  _FEATUREDTITLESVIEW._serialized_start=3117
  _FEATUREDTITLESVIEW._serialized_end=3511
  _FEATUREDTITLESVIEW_CONTENTS._serialized_start=3331
  _FEATUREDTITLESVIEW_CONTENTS._serialized_end=3511
  _FEATUREDTITLESVIEW_CONTENTS_DATACASE._serialized_start=3455
  _FEATUREDTITLESVIEW_CONTENTS_DATACASE._serialized_end=3511
  _FEATUREDTITLESVIEWV2._serialized_start=3514
  _FEATUREDTITLESVIEWV2._serialized_end=3802
  _FEATUREDTITLESVIEWV2_CONTENTS._serialized_start=3652
  _FEATUREDTITLESVIEWV2_CONTENTS._serialized_end=3802
  _FEEDBACK._serialized_start=3805
  _FEEDBACK._serialized_end=3950
  _FEEDBACK_RESPONSETYPE._serialized_start=3910
  _FEEDBACK_RESPONSETYPE._serialized_end=3950
  _FEEDBACKVIEW._serialized_start=3952
  _FEEDBACKVIEW._serialized_end=4013
  _HISTORYVIEW._serialized_start=4015
  _HISTORYVIEW._serialized_end=4118
  _HOMEVIEWV3._serialized_start=4121
  _HOMEVIEWV3._serialized_end=4416
  _HOMEVIEWV4._serialized_start=4419
  _HOMEVIEWV4._serialized_end=6769
  _HOMEVIEWV4_SECTIONS._serialized_start=4676
  _HOMEVIEWV4_SECTIONS._serialized_end=5159
  _HOMEVIEWV4_SECTIONS_SECTIONCASE._serialized_start=5019
  _HOMEVIEWV4_SECTIONS_SECTIONCASE._serialized_end=5159
  _HOMEVIEWV4_WEEKLYSECTION._serialized_start=5162
  _HOMEVIEWV4_WEEKLYSECTION._serialized_end=6223
  _HOMEVIEWV4_WEEKLYSECTION_WEEKLYCONTENT._serialized_start=5253
  _HOMEVIEWV4_WEEKLYSECTION_WEEKLYCONTENT._serialized_end=5388
  _HOMEVIEWV4_WEEKLYSECTION_CONTENTITEM._serialized_start=5391
  _HOMEVIEWV4_WEEKLYSECTION_CONTENTITEM._serialized_end=5930
  _HOMEVIEWV4_WEEKLYSECTION_CONTENTITEM_CONTENTCASE._serialized_start=5800
  _HOMEVIEWV4_WEEKLYSECTION_CONTENTITEM_CONTENTCASE._serialized_end=5930
  _HOMEVIEWV4_WEEKLYSECTION_MVBANNER._serialized_start=5932
  _HOMEVIEWV4_WEEKLYSECTION_MVBANNER._serialized_end=6016
  _HOMEVIEWV4_WEEKLYSECTION_TITLEGROUP._serialized_start=6018
  _HOMEVIEWV4_WEEKLYSECTION_TITLEGROUP._serialized_end=6086
  _HOMEVIEWV4_WEEKLYSECTION_CAROUSELBANNER._serialized_start=6088
  _HOMEVIEWV4_WEEKLYSECTION_CAROUSELBANNER._serialized_end=6144
  _HOMEVIEWV4_WEEKLYSECTION_MINORLANGUAGEBANNER._serialized_start=6146
  _HOMEVIEWV4_WEEKLYSECTION_MINORLANGUAGEBANNER._serialized_end=6223
  _HOMEVIEWV4_RANKINGSECTION._serialized_start=6226
  _HOMEVIEWV4_RANKINGSECTION._serialized_end=6434
  _HOMEVIEWV4_RANKINGSECTION_RANKINGTAB._serialized_start=6318
  _HOMEVIEWV4_RANKINGSECTION_RANKINGTAB._serialized_end=6434
  _HOMEVIEWV4_PREVIEWSECTION._serialized_start=6437
  _HOMEVIEWV4_PREVIEWSECTION._serialized_end=6647
  _HOMEVIEWV4_PREVIEWSECTION_PREVIEWTAB._serialized_start=6529
  _HOMEVIEWV4_PREVIEWSECTION_PREVIEWTAB._serialized_end=6647
  _HOMEVIEWV4_TITLELISTSECTION._serialized_start=6649
  _HOMEVIEWV4_TITLELISTSECTION._serialized_end=6712
  _HOMEVIEWV4_BANNERSECTION._serialized_start=6714
  _HOMEVIEWV4_BANNERSECTION._serialized_end=6769
  _INITIALVIEWV2._serialized_start=6771
  _INITIALVIEWV2._serialized_end=6880
  _INTRODUCESUBSCRIPTION._serialized_start=6882
  _INTRODUCESUBSCRIPTION._serialized_end=6977
  _LABELEDVIEW._serialized_start=6979
  _LABELEDVIEW._serialized_end=7092
  _LABEL._serialized_start=7094
  _LABEL._serialized_end=7164
  _LANGUAGES._serialized_start=7167
  _LANGUAGES._serialized_end=7475
  _AVAILABLELANGUAGES._serialized_start=7477
  _AVAILABLELANGUAGES._serialized_end=7561
  _MANGAVIEWER._serialized_start=7564
  _MANGAVIEWER._serialized_end=8247
  _MANGAVIEWER_TITLEAVAILABLELANGUAGES._serialized_start=8147
  _MANGAVIEWER_TITLEAVAILABLELANGUAGES._serialized_end=8247
  _METAINFO._serialized_start=8249
  _METAINFO._serialized_end=8303
  _MPCSTATUSVIEW._serialized_start=8305
  _MPCSTATUSVIEW._serialized_end=8374
  _PAGE._serialized_start=8377
  _PAGE._serialized_end=9909
  _PAGE_MANGAPAGE._serialized_start=8652
  _PAGE_MANGAPAGE._serialized_end=8779
  _PAGE_LASTPAGE._serialized_start=8782
  _PAGE_LASTPAGE._serialized_end=9599
  _PAGE_BANNERLIST._serialized_start=9601
  _PAGE_BANNERLIST._serialized_end=9674
  _PAGE_CHAPTERTYPE._serialized_start=9676
  _PAGE_CHAPTERTYPE._serialized_end=9731
  _PAGE_PAGETYPE._serialized_start=9733
  _PAGE_PAGETYPE._serialized_end=9788
  _PAGE_DATACASE._serialized_start=9790
  _PAGE_DATACASE._serialized_end=9909
  _POPUP._serialized_start=9912
  _POPUP._serialized_end=10738
  _POPUP_OSDEFAULT._serialized_start=10141
  _POPUP_OSDEFAULT._serialized_end=10376
  _POPUP_APPDEFAULT._serialized_start=10378
  _POPUP_APPDEFAULT._serialized_end=10488
  _POPUP_ONEIMAGE._serialized_start=10490
  _POPUP_ONEIMAGE._serialized_end=10567
  _POPUP_BUTTON._serialized_start=10569
  _POPUP_BUTTON._serialized_end=10640
  _POPUP_POPUPCASE._serialized_start=10642
  _POPUP_POPUPCASE._serialized_end=10738
  _MOVIEREWARD._serialized_start=10740
  _MOVIEREWARD._serialized_end=10824
  _PROFILESETTINGSVIEW._serialized_start=10827
  _PROFILESETTINGSVIEW._serialized_end=10956
  _PUBLISHERNEWSLISTVIEW._serialized_start=10959
  _PUBLISHERNEWSLISTVIEW._serialized_end=11113
  _PUBLISHERNEWS._serialized_start=11116
  _PUBLISHERNEWS._serialized_end=11295
  _PUSHTOKENVIEW._serialized_start=11297
  _PUSHTOKENVIEW._serialized_end=11351
  _QUESTIONNAIRE._serialized_start=11354
  _QUESTIONNAIRE._serialized_end=11491
  _QUESTIONNAIREVIEW._serialized_start=11494
  _QUESTIONNAIREVIEW._serialized_end=11642
  _REGISTRATIONDATA._serialized_start=11644
  _REGISTRATIONDATA._serialized_end=11684
  _RESPONSE._serialized_start=11687
  _RESPONSE._serialized_end=11845
  _RESPONSE_RESULTCASE._serialized_start=11789
  _RESPONSE_RESULTCASE._serialized_end=11845
  _SEARCHVIEW._serialized_start=11848
  _SEARCHVIEW._serialized_end=12307
  _SEARCHVIEW_CONTENTS._serialized_start=12058
  _SEARCHVIEW_CONTENTS._serialized_end=12307
  _SERVICEANNOUNCEMENT._serialized_start=12309
  _SERVICEANNOUNCEMENT._serialized_end=12385
  _SERVICEANNOUNCEMENTSVIEW._serialized_start=12387
  _SERVICEANNOUNCEMENTSVIEW._serialized_end=12479
  _SETTINGSVIEW._serialized_start=12482
  _SETTINGSVIEW._serialized_end=12688
  _SETTINGSVIEWV2._serialized_start=12691
  _SETTINGSVIEWV2._serialized_end=13123
  _CUSTOMCODEDIALOGUE._serialized_start=13125
  _CUSTOMCODEDIALOGUE._serialized_end=13163
  _SNS._serialized_start=13165
  _SNS._serialized_end=13197
  _SUBSCRIBEDTITLESVIEW._serialized_start=13200
  _SUBSCRIBEDTITLESVIEW._serialized_end=13350
  _IOSSUBSCRIPTIONOFFER._serialized_start=13353
  _IOSSUBSCRIPTIONOFFER._serialized_end=13594
  _IOSSUBSCRIPTIONOFFER_OFFERTYPE._serialized_start=13534
  _IOSSUBSCRIPTIONOFFER_OFFERTYPE._serialized_end=13594
  _ANDROIDSUBSCRIPTIONOFFERTAGS._serialized_start=13596
  _ANDROIDSUBSCRIPTIONOFFERTAGS._serialized_end=13639
  _SUBSCRIPTION._serialized_start=13642
  _SUBSCRIPTION._serialized_end=13773
  _PLANTYPE._serialized_start=13776
  _PLANTYPE._serialized_end=13975
  _SUBSCRIPTIONVIEW._serialized_start=13978
  _SUBSCRIPTIONVIEW._serialized_end=14349
  _SUBSCRIPTIONPLANBOXDESCRIPTION._serialized_start=14351
  _SUBSCRIPTIONPLANBOXDESCRIPTION._serialized_end=14412
  _SUBSCRIPTIONNOTE._serialized_start=14414
  _SUBSCRIPTIONNOTE._serialized_end=14461
  _SUCCESSRESULT._serialized_start=14464
  _SUCCESSRESULT._serialized_end=17573
  _SUCCESSRESULT_DATACASE._serialized_start=16680
  _SUCCESSRESULT_DATACASE._serialized_end=17573
  _TAG._serialized_start=17575
  _TAG._serialized_end=17607
  _TITLEDETAILVIEW._serialized_start=17610
  _TITLEDETAILVIEW._serialized_end=19922
  _TITLEDETAILVIEW_TITLELABELS._serialized_start=19132
  _TITLEDETAILVIEW_TITLELABELS._serialized_end=19208
  _TITLEDETAILVIEW_PUBLISHERITEM._serialized_start=19210
  _TITLEDETAILVIEW_PUBLISHERITEM._serialized_end=19317
  _TITLEDETAILVIEW_TITLELANGUAGES._serialized_start=19319
  _TITLEDETAILVIEW_TITLELANGUAGES._serialized_end=19395
  _TITLEDETAILVIEW_CHAPTERGROUP._serialized_start=19398
  _TITLEDETAILVIEW_CHAPTERGROUP._serialized_end=19583
  _TITLEDETAILVIEW_RELEASESCHEDULE._serialized_start=19586
  _TITLEDETAILVIEW_RELEASESCHEDULE._serialized_end=19727
  _TITLEDETAILVIEW_UPDATETIMING._serialized_start=19730
  _TITLEDETAILVIEW_UPDATETIMING._serialized_end=19864
  _TITLEDETAILVIEW_RATING._serialized_start=19866
  _TITLEDETAILVIEW_RATING._serialized_end=19922
  _ALLTITLESGROUP._serialized_start=19925
  _ALLTITLESGROUP._serialized_end=20103
  _TITLERANKINGGROUP._serialized_start=20105
  _TITLERANKINGGROUP._serialized_end=20202
  _TITLEUPDATEDGROUP._serialized_start=20204
  _TITLEUPDATEDGROUP._serialized_end=20306
  _LABELEDTITLESGROUP._serialized_start=20308
  _LABELEDTITLESGROUP._serialized_end=20384
  _TITLESUBSCRIPTIONGROUP._serialized_start=20386
  _TITLESUBSCRIPTIONGROUP._serialized_end=20486
  _TITLELIST._serialized_start=20488
  _TITLELIST._serialized_end=20584
  _CHAPTERPAGELIST._serialized_start=20586
  _CHAPTERPAGELIST._serialized_end=20672
  _CHAPTERPAGES._serialized_start=20675
  _CHAPTERPAGES._serialized_end=20838
  _TITLE._serialized_start=20841
  _TITLE._serialized_end=21097
  _UPDATEDTITLE._serialized_start=21100
  _UPDATEDTITLE._serialized_end=21284
  _TITLEUPDATED._serialized_start=21286
  _TITLEUPDATED._serialized_end=21368
  _FREETITLE._serialized_start=21370
  _FREETITLE._serialized_end=21449
  _TICKETTITLES._serialized_start=21451
  _TICKETTITLES._serialized_end=21557
  _SUBSCRIBABLETITLE._serialized_start=21559
  _SUBSCRIBABLETITLE._serialized_end=21655
  _COMINGSOONTITLE._serialized_start=21657
  _COMINGSOONTITLE._serialized_end=21771
  _TITLEHIGHLIGHT._serialized_start=21774
  _TITLEHIGHLIGHT._serialized_end=21955
  _TITLERANKINGVIEW._serialized_start=21957
  _TITLERANKINGVIEW._serialized_end=22013
  _TITLERANKINGVIEWV2._serialized_start=22016
  _TITLERANKINGVIEWV2._serialized_end=22165
  _TITLEUPDATEDVIEW._serialized_start=22167
  _TITLEUPDATEDVIEW._serialized_end=22235
  _TITLEUPDATEDVIEWV2._serialized_start=22237
  _TITLEUPDATEDVIEWV2._serialized_end=22318
  _TRANSITIONACTION._serialized_start=22321
  _TRANSITIONACTION._serialized_end=22477
  _TRANSITIONACTION_PRESENTATIONMETHOD._serialized_start=22422
  _TRANSITIONACTION_PRESENTATIONMETHOD._serialized_end=22477
  _UPDATEDTITLEGROUP._serialized_start=22479
  _UPDATEDTITLEGROUP._serialized_end=22562
  _UPDATEDTITLEV2GROUP._serialized_start=22564
  _UPDATEDTITLEV2GROUP._serialized_end=22683
  _ORIGINALTITLEGROUP._serialized_start=22686
  _ORIGINALTITLEGROUP._serialized_end=22898
  _UPDATEDTITLELISTVIEW._serialized_start=22900
  _UPDATEDTITLELISTVIEW._serialized_end=22972
  _UPDATEPROFILERESULTVIEW._serialized_start=22975
  _UPDATEPROFILERESULTVIEW._serialized_end=23115
  _UPDATEPROFILERESULTVIEW_RESULT._serialized_start=23065
  _UPDATEPROFILERESULTVIEW_RESULT._serialized_end=23115
  _USERTICKETS._serialized_start=23117
  _USERTICKETS._serialized_end=23183
  _WEBHOMEVIEWV4._serialized_start=23186
  _WEBHOMEVIEWV4._serialized_end=23509
# @@protoc_insertion_point(module_scope)
